<?php

namespace App\Bot;

class Bot
{
    public function sendMessage($chatId, $text, $replyMarkup = null)
    {
        $request_url = "https://api.telegram.org/bot" . BOT_TOKEN . "/sendMessage";
        $data = [
            'chat_id' => $chatId,
            'text' => $text,
            'parse_mode' => 'HTML'
        ];

        if ($replyMarkup)
        {
            $data['reply_markup'] = $replyMarkup;
        }

        // Make sure to return the response
        return file_get_contents($request_url . '?' . http_build_query($data));
    }

    
    public function get_user_data() : string
    {
        return file_get_contents('php://input');
    }

    public function decode_user_data() : array
    {
        $rawData = $this->get_user_data();
        return json_decode($rawData, true) ?? [];
    }

    public function answerCallbackQuery($callbackQueryId, $text = '', $showAlert = false)
    {
        $request_url = "https://api.telegram.org/bot" . BOT_TOKEN . "/answerCallbackQuery";
        $data = [
            'callback_query_id' => $callbackQueryId,
            'text' => $text,
            'show_alert' => $showAlert ? 'true' : 'false'
        ];

        file_get_contents($request_url . '?' . http_build_query($data));
    }

    public function edit_message_text(int $chatId, int $messageId, string $text, $replyMarkup = null, $parse = 'HTML')
    {
        $request_url = "https://api.telegram.org/bot" . BOT_TOKEN . "/editMessageText";
        $data = 
        [
            'chat_id' => $chatId,
            'message_id' => $messageId,
            'text' => $text,
            'parse_mode' => $parse
        ];

        if ($replyMarkup)
        {
            $data['reply_markup'] = $replyMarkup;
        }
        
        $ch = curl_init($request_url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($data));
        curl_setopt($ch, CURLOPT_HTTPHEADER, ['Content-Type: application/x-www-form-urlencoded']);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);

        $response = curl_exec($ch);
        $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        curl_close($ch);

        // error_log("HTTP Code: " . $httpCode);
        // error_log("Response: " . $response);

        if ($response === false)
        {
            $error = curl_error($ch);
            //error_log("CURL Error: " . $error);
        }
    }

    public function send_photo_to_admins(int $adminChatId, string $photoFileId, string $caption, $inlineKeyboard)
    {
        $request_url = "https://api.telegram.org/bot" . BOT_TOKEN . "/sendPhoto";
        $data = [
            'chat_id' => $adminChatId,
            'photo' => $photoFileId,
            'caption' => $caption,
            'reply_markup' => $inlineKeyboard
        ];

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $request_url);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $data);

        $response = curl_exec($ch);
        curl_close($ch);
    }

    public function delete_message(int $chatId, int $messageId)
    {
        $request_url = "https://api.telegram.org/bot" . BOT_TOKEN . "/deleteMessage";
        $data =
        [
            'chat_id' => $chatId,
            'message_id' => $messageId
        ];

        $ch = curl_init($request_url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($data));
        $response = curl_exec($ch);
        curl_close($ch);

        return $response;
    }

    public function send_photo($chatId, $photoPath, $caption)
    {
        $telegramApiUrl = "https://api.telegram.org/bot" . BOT_TOKEN . "/sendPhoto";

        $postData =
        [
            'chat_id' => $chatId,
            'photo'   => new \CURLFile($photoPath),
            'caption' => $caption
        ];

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $telegramApiUrl);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $postData);

        $response = curl_exec($ch);

        if (curl_errno($ch))
        {
            return 'Error:' . curl_error($ch);
        }

        curl_close($ch);

        return $response;
    }
}
