<?php

namespace App\Db;

class AdminStatusManager
{
    private $pdo;

    public function __construct($pdo)
    {
        $this->pdo = $pdo;
    }

    public function save_admin_status(int $chatId, string $status, array $linkStatus = [])
    {
        $linkStatusJson = json_encode($linkStatus);

        $stmt = $this->pdo->prepare("
        INSERT INTO admins (admin_chat_id, status, link_status)
        VALUES (:chatId, :status, :linkStatus)
        ON DUPLICATE KEY UPDATE status = VALUES(status), link_status = VALUES(link_status)
        ");
        
        $stmt->execute([
            'chatId' => $chatId,
            'status' => $status,
            'linkStatus' => $linkStatusJson
        ]);
    }

    public function load_admin_status($chatId)
    {
        $stmt = $this->pdo->prepare("SELECT status, link_status FROM admins WHERE admin_chat_id = :chatId");
        $stmt->execute(['chatId' => $chatId]);
        $result = $stmt->fetch(\PDO::FETCH_ASSOC);

        if(!$result)
        {
            return
            [
                'admin_status' => '',
                'link_status' => []
            ];
        }

        return 
        [
            'admin_status' => $result['status'],
            'link_status' => json_decode($result['link_status'],true)
        ];
    }

    public function get_phone_number_config()
    {
        $stmt = $this->pdo->prepare("SELECT phone_number_required FROM configs WHERE id = :id");
        $stmt->execute(['id' => 1 ]);
        
        return $result = $stmt->fetchColumn();
    }

    public function must_share_phone_number()
    {
        $result = $this->get_phone_number_config();

        if($result == null)
        {
            $stmt = $this->pdo->prepare("INSERT INTO configs (phone_number_required) VALUES (:phone_number_required)");
            $stmt->execute(['phone_number_required' => true]);
        }
        else
        {
            if($result == true)
                $value = false;
            else
                $value = true;

            $stmt = $this->pdo->prepare("UPDATE configs SET phone_number_required = :phone_number_required WHERE id = :id");
            $stmt->execute([
                'phone_number_required' => $value,
                'id' => 1
            ]);
        }
    }

    
}