<?php

namespace App\Db;

class Payment
{
    private $pdo;

    public function __construct($pdo)
    {
        $this->pdo = $pdo;
    }

    public function add_transaction(int $user_id, string $type, float $amount, string $status) : void
    {
        $stmt = $this->pdo->prepare("
            INSERT INTO transactions (user_id, transaction_type, amount, status) 
            VALUES (:user_id, :transaction_type, :amount, :status)
        ");
        $stmt->execute([
            'user_id' => $user_id,
            'transaction_type' => $type,
            'amount' => $amount,
            'status' => $status
        ]);
    }


    public function update_transaction(int $user_id, string $status) : void
    {
        $stmt = $this->pdo->prepare("UPDATE transactions SET status = :status WHERE user_id = :user_id");
        $stmt->execute([
            'user_id' => $user_id,
            'status' => $status
        ]);
    }

    public function update_transaction_status(int $transactionId, string $status) : void
    {
        $stmt = $this->pdo->prepare("UPDATE transactions SET status = :status WHERE id = :transaction_id");
        $stmt->execute([
            'status' => $status,
            'transaction_id' => $transactionId
        ]);
    }

    public function get_user_last_transaction_status(int $user_id) : ?array
    {
        $stmt = $this->pdo->prepare("SELECT status FROM transactions WHERE user_id = :user_id ORDER BY created_at DESC LIMIT 1");
        $stmt->execute(['user_id' => $user_id]);
        return $result = $stmt->fetch(\PDO::FETCH_ASSOC) ?? null;
    }

    public function get_user_last_transaction_amount(int $user_id) : ?array
    {
        $stmt = $this->pdo->prepare("SELECT amount FROM transactions WHERE user_id = :user_id ORDER BY created_at DESC LIMIT 1");
        $stmt->execute(['user_id' => $user_id]);
        return $result = $stmt->fetch(\PDO::FETCH_ASSOC) ?? null;
    }

    public function get_user_last_transaction_id(int $user_id) : ?array
    {
        $stmt = $this->pdo->prepare("SELECT id FROM transactions WHERE user_id = :user_id ORDER BY created_at DESC LIMIT 1");
        $stmt->execute(['user_id' => $user_id]);
        return $result = $stmt->fetch(\PDO::FETCH_ASSOC) ?? null;
    }

    public function get_transacton_by_id(int $transactionId)
    {
        $stmt = $this->pdo->prepare("SELECT user_id, amount FROM transactions WHERE id = :id ORDER BY created_at DESC LIMIT 1");
        $stmt->execute(['id' => $transactionId]);
        return $result = $stmt->fetch(\PDO::FETCH_ASSOC) ?? null;
    }

    public function increase_balance(int $chatId, $amount)
    {
        $stmt = $this->pdo->prepare("UPDATE users SET balance = balance + :amount WHERE user_id = :chatId");
        $stmt->execute([
            'amount' => $amount,
            'chatId' => $chatId
        ]);
    }

    public function decrease_balance(int $chatId, $amount)
    {
        $stmt = $this->pdo->prepare("UPDATE users SET balance = balance - :amount WHERE user_id = :chatId");
        $stmt->execute([
            'amount' => $amount,
            'chatId' => $chatId
        ]);
    }

    public function add_or_update_transaction(int $user_id, string $type, float $amount, string $status) : void
    {
        # Checking if user has already a transaction
        $stmt = $this->pdo->prepare("
            SELECT id 
            FROM transactions 
            WHERE user_id = :user_id 
            ORDER BY created_at DESC 
            LIMIT 1
        ");
        $stmt->execute(['user_id' => $user_id]);
        $transaction = $stmt->fetch();

        if ($transaction)
        {
            # If user has transaction
            $stmt = $this->pdo->prepare("
                UPDATE transactions
                SET transaction_type = :transaction_type, amount = :amount, status = :status
                WHERE id = :id
            ");
            $stmt->execute([
                'transaction_type' => $type,
                'amount' => $amount,
                'status' => $status,
                'id' => $transaction['id']
            ]);
        }
        else
        {
            $stmt = $this->pdo->prepare("
                INSERT INTO transactions (user_id, transaction_type, amount, status) 
                VALUES (:user_id, :transaction_type, :amount, :status)
            ");
            $stmt->execute([
                'user_id' => $user_id,
                'transaction_type' => $type,
                'amount' => $amount,
                'status' => $status
            ]);
        }
    }

}
