<?php

namespace App\Db;

class Price
{
    private $pdo;

    public function __construct($pdo)
    {
        $this->pdo = $pdo;
    }

    public function is_it_time_to_refresh_price(int $currentTimestamp) : bool
    {
        $stmt = $this->pdo->prepare("SELECT updated_at FROM price ORDER BY updated_at DESC LIMIT 1");
        $stmt->execute();
        $lastUpdatedDatetime = $stmt->fetchColumn();

        $lastUpdatedTimestamp = strtotime($lastUpdatedDatetime);

        $refreshInterval = 5 * 60;

        return ($currentTimestamp - $lastUpdatedTimestamp) > $refreshInterval;
    }

    public function refresh_price(float|int $price) : void
    {
        $stmt = $this->pdo->prepare("UPDATE price SET price = :price, updated_at = :updated_at WHERE id = :id");
        $stmt->execute([
            'price' => $price,
            'updated_at' => date("Y-m-d H:i:s"),
            'id' => 1
        ]);
    }

    public function get_price()
    {
        $stmt = $this->pdo->prepare("SELECT price FROM price");
        $stmt->execute();
        return $stmt->fetchColumn();
    }

    public function set_profit(float $profit) : void
    {
        $stmt = $this->pdo->prepare("UPDATE price SET profit = :profit WHERE id = :id");
        $stmt->execute([
            'profit' => $profit,
            'id' => 1
        ]);
    }

    public function get_profit() : float
    {
        $stmt = $this->pdo->prepare("SELECT profit FROM price WHERE id = :id");
        $stmt->execute(['id' => 1]);
        return $stmt->fetchColumn();
    }
}