<?php

namespace App\Db;

class UserPurchases
{
    private $pdo;

    public function __construct($pdo)
    {
        $this->pdo = $pdo;
    }

    public function add_user_purchase(int $user_id, string $number, string $order_id, string $country, string $service, int $pool, float $cost, float $toman)
    {
        $stmt = $this->pdo->prepare("INSERT INTO user_purchases (user_id, number, order_id, country, service, pool, cost, price_in_toman)
                                    VALUES (:user_id, :number, :order_id, :country, :service, :pool, :cost, :price_in_toman)");
        $stmt->execute([
            'user_id' => $user_id,
            'number' => $number,
            'order_id' => $order_id,
            'country' => $country,
            'service' => $service,
            'pool' => $pool,
            'cost' => $cost,
            'price_in_toman' => $toman
        ]);
    }

    public function get_user_last_transactionId(int $userId)
    {
        $stmt = $this->pdo->prepare("SELECT id FROM user_purchases WHERE user_id = :user_id ORDER BY created_at DESC LIMIT 1");
        $stmt->execute([
            'user_id' => $userId
        ]);
        $result = $stmt->fetch(\PDO::FETCH_ASSOC);
        return $result['id'];
    }

    public function get_user_last_transactionPrice(int $userId)
    {
        $stmt = $this->pdo->prepare("SELECT price_in_toman FROM user_purchases WHERE user_id = :user_id ORDER BY created_at DESC LIMIT 1");
        $stmt->execute([
            'user_id' => $userId
        ]);
        $result = $stmt->fetch(\PDO::FETCH_ASSOC);
        return $result['price_in_toman'];
    }

    public function update_user_purchase_status(int $transactionId, string $status)
    {
        $stmt = $this->pdo->prepare("UPDATE user_purchases SET status = :status WHERE id = :id");
        $stmt->execute([
            'status' => $status,
            'id' => $transactionId
        ]);
    }

    public function get_all_user_purchases(int $user_id) : ?array
    {
        $stmt = $this->pdo->prepare("SELECT * FROM user_purchases WHERE user_id = :user_id");
        $stmt->execute(['user_id' => $user_id]);
        return $stmt->fetchAll(\PDO::FETCH_ASSOC) ?? null;
    }
}