<?php

namespace App\Db;

class UserStatusManager
{
    private $pdo;

    public function __construct($pdo)
    {
        $this->pdo = $pdo;
    }

    public function add_user(array $userdata) : void
    {
        $stmt = $this->pdo->prepare("INSERT INTO users (user_id, first_name, username) VALUES (:user_id, :first_name, :username)");
    
        $stmt->execute([
            ':user_id' => $userdata['message']['chat']['id'],
            ':first_name' => $userdata['message']['chat']['first_name'],
            ':username' => $userdata['message']['chat']['username'] ?? null
        ]);
    }

    public function update_user_state(int $chatId) : void
    {
        $stmt = $this->pdo->prepare("UPDATE users SET state = :state WHERE user_id = :user_id");
        $stmt->execute([
            'state' => 1,
            'user_id' => $chatId
        ]);
    }

    public function update_user_status(int $chatId, string $status) : void
    {
        $stmt = $this->pdo->prepare("UPDATE users SET status = :status WHERE user_id = :user_id");
        $stmt->execute([
            'status' => $status,
            'user_id' => $chatId
        ]);
    }

    

    public function get_user_state(int $chatId) : ?int
    {
        $stmt = $this->pdo->prepare("SELECT state FROM users WHERE user_id = :user_id");
        $stmt->execute(['user_id' => $chatId]);
        $result = $stmt->fetch(\PDO::FETCH_ASSOC);
        
        return $result['state'] ?? null;
    }

    public function get_user_status(int $chatId) : ?string
    {
        $stmt = $this->pdo->prepare("SELECT status FROM users WHERE user_id = :user_id");
        $stmt->execute(['user_id' => $chatId]);
        $result = $stmt->fetch(\PDO::FETCH_ASSOC);
        
        return $result['status'] ?? null;
    }

    public function get_user_info(int $chatId) : array
    {
        $stmt = $this->pdo->prepare("SELECT first_name, username, user_id FROM users WHERE user_id = :user_id");
        $stmt->execute(['user_id' => $chatId]);
        return $result = $stmt->fetch(\PDO::FETCH_ASSOC);
    }

    public function get_user_balance(int $chatId)
    {
        $stmt = $this->pdo->prepare("SELECT balance FROM users WHERE user_id = :user_id");
        $stmt->execute(['user_id' => $chatId]);
        return $result = $stmt->fetch(\PDO::FETCH_ASSOC)['balance']?? null;
    }

    public function is_user_blocked(int $chatId) : bool
    {
        $stmt = $this->pdo->prepare("SELECT 1 FROM blocked_users WHERE user_chat_id = :user_chat_id");
        $stmt->execute(['user_chat_id' => $chatId]);
        
        if($stmt->fetchColumn())
        {
            return true;
        }

        $stmt = $this->pdo->prepare("INSERT INTO blocked_users (user_chat_id) VALUES (:user_chat_id)");
        $stmt->execute(['user_chat_id' => $chatId]);

        return false;
    }

    public function check_user_block_situation(int $chatId) : bool
    {
        $stmt = $this->pdo->prepare("SELECT 1 FROM blocked_users WHERE user_chat_id = :user_chat_id");
        $stmt->execute(['user_chat_id' => $chatId]);
        
        if($stmt->fetchColumn())
        {
            return true;
        }

        return false;
    }

    public function block_user(int $chatId, string $description)
    {
        $stmt = $this->pdo->prepare("UPDATE blocked_users SET Description = :Description WHERE user_chat_id = :user_chat_id");
        $stmt->execute([
            'user_chat_id' => $chatId,
            'Description' => $description
        ]);
    }

    public function save_temp_user_block_data(string $key, int|string $value, int $chatId)
    {
        $stmt = $this->pdo->prepare("UPDATE blocked_users SET $key = :value WHERE user_chat_id = :user_chat_id");
        $stmt->execute([
            'value' => $$value,
            'user_chat_id' => $chatId
        ]);
    }

    public function get_block_reason(int $chatId)
    {
        $stmt = $this->pdo->prepare("SELECT Description FROM blocked_users WHERE user_chat_id = :user_chat_id");
        $stmt->execute(['user_chat_id' => $chatId]);
        
        return $stmt->fetchColumn();
    }

    public function unblock_user(int $chatId)
    {
        if($this->check_user_block_situation($chatId) == true)
        {
            $stmt = $this->pdo->prepare("DELETE FROM blocked_users WHERE user_chat_id = :user_chat_id");
            $stmt->execute(['user_chat_id' => $chatId]);

            return true;
        }
        else
            return false;
    }
    public function save_temp_data(int $addedBy, int $normalUserId)
    {
        $stmt = $this->pdo->prepare("SELECT id FROM temp WHERE added_by = :added_by");
        $stmt->execute(['added_by' => $addedBy]);
        $result = $stmt->fetchColumn();

        if($result)
        {
            $stmt = $this->pdo->prepare("UPDATE temp SET normal_user_chat_id = :normal_user_chat_id WHERE added_by = :added_by");
            $stmt->execute([
                'normal_user_chat_id' => $normalUserId,
                'added_by' => $addedBy
            ]);
        }
        else
        {
            $stmt = $this->pdo->prepare("INSERT INTO temp (added_by, normal_user_chat_id) VALUES (:added_by, :normal_user_chat_id)");
            $stmt->execute([
                'added_by' => $addedBy,
                'normal_user_chat_id' => $normalUserId
            ]);
        }
    }

    public function get_temp_data(int $addedBy)
    {
        $stmt = $this->pdo->prepare("SELECT normal_user_chat_id FROM temp WHERE added_by = :added_by");
        $stmt->execute(['added_by' => $addedBy]);
        return $stmt->fetchColumn();
    }

    public function clear_temp_data(int $addedBy)
    {
        $stmt = $this->pdo->prepare("DELETE FROM temp WHERE added_by = :added_by");
        $stmt->execute(['added_by' => $addedBy]);
    }

    public function get_all_user_chat_ids()
    {
        $stmt = $this->pdo->prepare("SELECT user_id FROM users");
        $stmt->execute();
        return $stmt->fetchAll();
    }

    public function get_all_user_info(int $chatId)
    {
        $stmt = $this->pdo->prepare("SELECT * FROM users WHERE user_id = :user_id");
        $stmt->execute(['user_id' => $chatId]);
        $userBasicInfo = $stmt->fetchAll(\PDO::FETCH_ASSOC);

        $stmt = $this->pdo->prepare("SELECT * FROM user_purchases WHERE user_id = :user_id");
        $stmt->execute(['user_id' => $chatId]);
        $userPurchaseInfo = $stmt->fetchAll(\PDO::FETCH_ASSOC);

        return
        [
            'userBasicInfo' => $userBasicInfo,
            'userPurchaseInfo' => $userPurchaseInfo
        ];
    }

    public function save_phone_number(int $chatId, string $phoneNumber)
    {
        $stmt = $this->pdo->prepare("UPDATE users SET phone_number = :phone_number WHERE user_id = :user_id");
        $stmt->execute([
            'phone_number' => $phoneNumber,
            'user_id' => $chatId
        ]);
    }

    public function set_bank_card(string $key, int|string $value)
    {
        $stmt = $this->pdo->prepare("SELECT 1 FROM bank WHERE id = :id");
        $stmt->execute(['id' => 1]);
        
        if($stmt->fetchColumn())
        {
            $stmt = $this->pdo->prepare("UPDATE bank SET $key = :value WHERE id = :id");
            $stmt->execute([
                'value' => $value,
                'id' => 1
            ]);
        }
        else
        {
            $stmt = $this->pdo->prepare("INSERT INTO bank ($key) VALUES (:value)");
            $stmt->execute(['value' => $value]);
        }
    }

    public function get_bank_card()
    {
        $stmt = $this->pdo->prepare("SELECT * FROM bank WHERE id = :id");
        $stmt->execute(['id' => 1]);
        return $stmt->fetch(\PDO::FETCH_ASSOC);
    }

    public function get_phone_number_config()
    {
        $stmt = $this->pdo->prepare("SELECT phone_number_required FROM configs WHERE id = :id");
        $stmt->execute(['id' => 1]);
        
        return $stmt->fetchColumn();
    }

    public function must_share_phone_number()
    {
        $result = $this->get_phone_number_config();

        if($result === false || $result === null)
        {
            $stmt = $this->pdo->prepare("INSERT INTO configs (id, phone_number_required) VALUES (:id, :phone_number_required)");
            $stmt->execute(['id' => 1, 'phone_number_required' => true]);
        }
        else
        {
            $value = !$result;

            $stmt = $this->pdo->prepare("UPDATE configs SET phone_number_required = :phone_number_required WHERE id = :id");
            $stmt->execute([
                'phone_number_required' => $value,
                'id' => 1
            ]);
        }
    }

    public function delete_rejected_user(int $chatId)
    {
        $stmt = $this->pdo->prepare("DELETE FROM users WHERE user_id = :user_id");
        $stmt->execute(['user_id' => $chatId]);
    }

    public function get_bot_update_situation()
    {
        $stmt = $this->pdo->prepare("SELECT is_updating FROM configs WHERE id = :id");
        $stmt->execute(['id' => 1]);
        
        return $stmt->fetchColumn();
    }

    public function bot_updating()
    {
        $result = $this->get_bot_update_situation();

        $stmt = $this->pdo->prepare("UPDATE configs SET is_updating = :is_updating");
        $stmt->execute(['is_updating' => !$result]);
    }

    public function get_bot_user_approvment_situation()
    {
        $stmt = $this->pdo->prepare("SELECT admin_approve FROM configs WHERE id = :id");
        $stmt->execute(['id' => 1]);
        
        return $stmt->fetchColumn();
    }

    public function bot_user_approvment()
    {
        $result = $this->get_bot_user_approvment_situation();

        $stmt = $this->pdo->prepare("UPDATE configs SET admin_approve = :admin_approve");
        $stmt->execute(['admin_approve' => !$result]);
    }

    public function get_user_last_order_id(int $chatId)
    {
        $stmt = $this->pdo->prepare("SELECT order_id FROM user_purchases WHERE user_id = :user_id ORDER BY created_at DESC LIMIT 1");
        $stmt->bindParam(':user_id', $chatId, \PDO::PARAM_INT);
        $stmt->execute();
        
        return $stmt->fetchColumn();
    }

    public function get_user_last_phone_number_by_order_id($id)
    {
        $stmt = $this->pdo->prepare("SELECT number FROM user_purchases WHERE order_id = :order_id");
        $stmt->execute(['order_id' => $id]);
        
        return $stmt->fetchColumn();
    }

    public function add_tries(int $chatId, string $orderId)
    {
        $stmt = $this->pdo->prepare("UPDATE user_purchases SET tries = tries + 1 WHERE user_id = :user_id AND order_id = :order_id");
        $stmt->execute([
            'user_id' => $chatId,
            'order_id' => $orderId
        ]);
    }

    public function get_tries(int $chatId, string $orderId)
    {
        $stmt = $this->pdo->prepare("SELECT tries FROM user_purchases WHERE user_id = :user_id AND order_id = :order_id");
        $stmt->execute([
            'user_id' => $chatId,
            'order_id' => $orderId
        ]);
        return $stmt->fetchColumn();
    }


}