<?php

namespace App\Pay;

class VerifyPayment
{
    private $merchantId;
    private $url;

    public function __construct()
    {
        $this->merchantId = 'ea1e96f2-3fbe-11e6-b6c1-000c295eb8fc';
        $this->url = "https://api.zarinpal.com/pg/v4/payment/verify.json";
    }

    public function verifyPayment($amount, $authority)
    {
        $data = [
            'merchant_id' => $this->merchantId,
            'amount' => $amount,
            'authority' => $authority
        ];

        $ch = curl_init($this->url);
        curl_setopt_array($ch, [
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_POST => true,
            CURLOPT_HTTPHEADER => [
                "accept: application/json",
                "content-type: application/json"
            ],
            CURLOPT_POSTFIELDS => json_encode($data)
        ]);

        $response = curl_exec($ch);
        $error = curl_error($ch);
        curl_close($ch);

        if ($error)
        {
            return [
                'success' => false,
                'error' => "Part1 Error:" . $error
            ];
        }

        $result = json_decode($response, true);

        if ($result === null) {
            return [
                'success' => false,
                'error' => 'Failed to decode JSON response'
            ];
        }

        # Check if 'data' and 'code' exist in the response
        if (isset($result['data']) && isset($result['data']['code']) && $result['data']['code'] == 100)
        {
            return [
                'success' => true,
                'data' => $result['data']
            ];
        }
        else
        {
            $errorMessage = isset($result['data']['message']) ? $result['data']['message'] : 'Part 2: Unknown error';
            return [
                'success' => false,
                'error' => $errorMessage
            ];
        }
    }
}
