<?php

namespace App\SmsPool;

use App\Utility\Util;

class CountryList
{
    private $token;

    public function __construct(SmsPool $smsPool)
    {
        $this->token = $smsPool->getToken();
    }

    public function get_countries_by_service(string $service) : ?array
    {
        $curl = curl_init();
        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, false);

        curl_setopt_array($curl, array(
            CURLOPT_URL => 'https://api.smspool.net/request/suggested_countries',
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_ENCODING => '',
            CURLOPT_MAXREDIRS => 10,
            CURLOPT_TIMEOUT => 0,
            CURLOPT_FOLLOWLOCATION => true,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => 'POST',
            CURLOPT_POSTFIELDS => http_build_query(array('service' => $service)),
            CURLOPT_HTTPHEADER => array(
                'Authorization: Bearer ' . $this->token,
                'Content-Type: application/x-www-form-urlencoded'
            ),
        ));

        $response = curl_exec($curl);

        if ($response === false)
        {
            return 'Curl error: ' . curl_error($curl);
        }

        curl_close($curl);
        return json_decode($response,true) ?? null;
    }

    public function countries_pagination($pageIndex, $chunks, $botInstance, $keyboardInstance, $chatId, $messageId = null)
    {
        $currentChunk = $chunks[$pageIndex];
        $keyboardInstance->addInlineButton("نام کشور", "nonFunctional", null, 0);

        $row = 1;
        $counter = 0;
        foreach ($currentChunk as $countryList)
        {
            $countryName = Util::translateCountryName($countryList['name']);
            $keyboardInstance->addInlineButton($countryName['name'] . $countryName['flag'], "tgBtn_" . urlencode($countryList['name']), null, $row);
            $counter++;
            if($counter % 2 == 0)
                $row++;
        }
        
        

        if ($pageIndex > 0)
        {
            $keyboardInstance->addInlineButton("قبلی", "telegramBtn_page_" . ($pageIndex - 1), null, $row);
        }
        if ($pageIndex < count($chunks) - 1)
        {
            $keyboardInstance->addInlineButton("بعدی", "telegramBtn_page_" . ($pageIndex + 1), null, $row);
        }
        $row++;
        $keyboardInstance->addInlineButton("برگشت", "toServicesBtn", null, $row);
        $inlineKeyboard = $keyboardInstance->getInlineKeyboard();

        if ($messageId)
        {
            $botInstance->edit_message_text($chatId, $messageId, "لطفا کشور موردنظر خود را انتخاب کنید.", $inlineKeyboard);
        }
        else
        {
            $botInstance->sendMessage($chatId, "لطفا کشور موردنظر خود را انتخاب کنید.", $inlineKeyboard);
        }
    }

    public function countries_paginationw($pageIndex, $chunks, $botInstance, $keyboardInstance, $chatId, $messageId = null)
    {
        $currentChunk = $chunks[$pageIndex];
        $keyboardInstance->addInlineButton("نام کشور", "nonFunctional", null, 0);

        $row = 1;
        $counter = 0;
        foreach ($currentChunk as $countryList)
        {
            $countryName = Util::translateCountryName($countryList['name']);
            $keyboardInstance->addInlineButton($countryName['name'] . $countryName['flag'], "waBtn_" . urlencode($countryList['name']), null, $row);
            $counter++;
            if($counter % 2 == 0)
                $row++;
        }
        
        

        if ($pageIndex > 0)
        {
            $keyboardInstance->addInlineButton("قبلی", "waBtn_page_" . ($pageIndex - 1), null, $row);
        }
        if ($pageIndex < count($chunks) - 1)
        {
            $keyboardInstance->addInlineButton("بعدی", "waBtn_page_" . ($pageIndex + 1), null, $row);
        }
        $row++;
        $keyboardInstance->addInlineButton("برگشت", "toServicesBtn", null, $row);
        $inlineKeyboard = $keyboardInstance->getInlineKeyboard();

        if ($messageId)
        {
            $botInstance->edit_message_text($chatId, $messageId, "لطفا کشور موردنظر خود را انتخاب کنید.", $inlineKeyboard);
        }
        else
        {
            $botInstance->sendMessage($chatId, "لطفا کشور موردنظر خود را انتخاب کنید.", $inlineKeyboard);
        }
    }

    public function countries_paginationig($pageIndex, $chunks, $botInstance, $keyboardInstance, $chatId, $messageId = null)
    {
        $currentChunk = $chunks[$pageIndex];
        $keyboardInstance->addInlineButton("نام کشور", "nonFunctional", null, 0);

        $row = 1;
        $counter = 0;
        foreach ($currentChunk as $countryList)
        {
            $countryName = Util::translateCountryName($countryList['name']);
            $keyboardInstance->addInlineButton($countryName['name'] . $countryName['flag'], "igBtn_" . urlencode($countryList['name']), null, $row);
            $counter++;
            if($counter % 2 == 0)
                $row++;
        }
        
        

        if ($pageIndex > 0)
        {
            $keyboardInstance->addInlineButton("قبلی", "igBtn_page_" . ($pageIndex - 1), null, $row);
        }
        if ($pageIndex < count($chunks) - 1)
        {
            $keyboardInstance->addInlineButton("بعدی", "igBtn_page_" . ($pageIndex + 1), null, $row);
        }
        $row++;
        $keyboardInstance->addInlineButton("برگشت", "toServicesBtn", null, $row);
        $inlineKeyboard = $keyboardInstance->getInlineKeyboard();

        if ($messageId)
        {
            $botInstance->edit_message_text($chatId, $messageId, "لطفا کشور موردنظر خود را انتخاب کنید.", $inlineKeyboard);
        }
        else
        {
            $botInstance->sendMessage($chatId, "لطفا کشور موردنظر خود را انتخاب کنید.", $inlineKeyboard);
        }
    }

    public function countries_paginationapple($pageIndex, $chunks, $botInstance, $keyboardInstance, $chatId, $messageId = null)
    {
        $currentChunk = $chunks[$pageIndex];
        $keyboardInstance->addInlineButton("نام کشور", "nonFunctional", null, 0);

        $row = 1;
        $counter = 0;
        foreach ($currentChunk as $countryList)
        {
            $countryName = Util::translateCountryName($countryList['name']);
            $keyboardInstance->addInlineButton($countryName['name'] . $countryName['flag'], "appleBtn_" . urlencode($countryList['name']), null, $row);
            $counter++;
            if($counter % 2 == 0)
                $row++;
        }
        
        

        if ($pageIndex > 0)
        {
            $keyboardInstance->addInlineButton("قبلی", "appleBtn_page_" . ($pageIndex - 1), null, $row);
        }
        if ($pageIndex < count($chunks) - 1)
        {
            $keyboardInstance->addInlineButton("بعدی", "appleBtn_page_" . ($pageIndex + 1), null, $row);
        }
        $row++;
        $keyboardInstance->addInlineButton("برگشت", "toServicesBtn", null, $row);
        $inlineKeyboard = $keyboardInstance->getInlineKeyboard();

        if ($messageId)
        {
            $botInstance->edit_message_text($chatId, $messageId, "لطفا کشور موردنظر خود را انتخاب کنید.", $inlineKeyboard);
        }
        else
        {
            $botInstance->sendMessage($chatId, "لطفا کشور موردنظر خود را انتخاب کنید.", $inlineKeyboard);
        }
    }
}