<?php

use App\Bot\Bot;
use App\Bot\Keyboard;
//use App\Db\AdminStatusManager;
use App\Db\Db;
use App\Db\Payment;
use App\Db\Price;
use App\Db\UserPurchases;
use App\Db\UserStatusManager;
use App\SmsPool\BuyNumber;
use App\SmsPool\CancelSms;
use App\SmsPool\CheckSms;
use App\SmsPool\CountryList;
use App\SmsPool\CountryPrice;
use App\SmsPool\PoolList;
use App\SmsPool\SmsPool;
use App\Utility\Util;

include_once __DIR__ . "/../const.php";

# Creating objects of classes
$dbInstance = new Db(HOST, USERNAME, PASSWORD, DBNAME);
$pdo = $dbInstance->getConnection();
$normalUserInstance = new UserStatusManager($pdo);
$botInstance = new Bot();
$keyboardInstance = new Keyboard();
$smsPoolToken = SmsPool::getInstance();
$countryListInstance = new CountryList($smsPoolToken);
$countryPriceInstance = new CountryPrice($smsPoolToken);
$poolListInstance = new PoolList($smsPoolToken);
$buyNumberInstance = new BuyNumber($smsPoolToken);
$paymentInstance = new Payment($pdo);
$userPurchaseInstance = new UserPurchases($pdo);
$checkSmsInstance = new CheckSms($smsPoolToken);
$cancelSmsInstance = new CancelSms($smsPoolToken);
$priceInstance = new Price($pdo);

# Getting user data
$content = $botInstance->decode_user_data();

if (isset($content['message']))
{
    # Processing message
    $chatId = $content['message']['chat']['id'] ?? null;
    $message = $content['message']['text'] ?? null;
    $messageId = $content['message']['message_id'] ?? null;
    $phoneNumber = $content['message']['contact']['phone_number'] ?? null;
    $phoneNumber = $content['message']['contact']['phone_number'] ?? null;

    # Checking whether the user is an admin or a normal user
    if (in_array($chatId, $admin_chat_ids))
    {
        # User is an admin

        $userState = $normalUserInstance->get_user_state($chatId) ?? null;
        $userStatus = $normalUserInstance->get_user_status($chatId) ?? null;
        
        $currentAdmin = $chatId;
        $currentAdminName = $content['message']['chat']['first_name'];
        if($message == "/start" || $message == "/menu")
        {
            if($userState == 0 || $userState == null)
            {
                $normalUserInstance->add_user($content);
                $normalUserInstance->update_user_state($chatId);
                $text = "درود $currentAdminName جان.چه کاری میتونم برات انجام بدم؟";
            }
            elseif($userState == 1)
            {
                $text = "درود $currentAdminName جان. چه کاری میتونم برات انجام بدم؟";
            }
            
            $keyboardInstance->addInlineButton("💻 پنل",null,"https://customers.ahpbot.com/virtualNumber/App/Panel/index.php", 0);
            $keyboardInstance->addInlineButton("🚫 مسدود کردن کاربر", "blockBtn", null, 1);
            $keyboardInstance->addInlineButton("🆓 آزاد کردن کاربر", "unblockBtn", null, 1);
            $keyboardInstance->addInlineButton("📧 ارسال پیام خصوصی", "dmBtn", null, 2);
            $keyboardInstance->addInlineButton("👥📧 ارسال پیام گروهی", "groupDmBtn", null, 2);
            $keyboardInstance->addInlineButton("➕ افزایش موجودی", "adminChargingWallet", null, 3);
            $keyboardInstance->addInlineButton("➖ کاهش موجودی", "decreaseChargeWalletBtn", null, 3);
            $keyboardInstance->addInlineButton("ℹ نمایش اطلاعات کاربر", "showUserInfoBtn", null, 4);
            $keyboardInstance->addInlineButton("💳 تنظیم شماره حساب", "bankCardBtn", null, 5);
            $keyboardInstance->addInlineButton("📴 احراز هویت با شماره موبایل", "phoneNumberReuiredBtn", null, 6);
            $keyboardInstance->addInlineButton("👍👎 تایید ادمین برای احراز هویت", "userApprovmentByAdminBtn", null, 7);
            $keyboardInstance->addInlineButton("🤖 حالت به روزرسانی ربات", "botIsUpdatingdBtn", null, 8);
            $mainMenuKeyboard = $keyboardInstance->getInlineKeyboard();
            $botInstance->sendMessage($currentAdmin, $text, $mainMenuKeyboard);
        }
        elseif($userStatus == "blocking_user")
        {
            $userIdToBlock = (int)$message;

            if($normalUserInstance->is_user_blocked($userIdToBlock) == true)
            {
                $botInstance->sendMessage($chatId, "این کاربر از قبل مسدود شده است.");
                return;
            }
            else
            {
                $normalUserInstance->update_user_status($chatId, "blocking_user_description_$userIdToBlock");
                $text = "لطفا دلیل مسدود کردن کاربر را در قالب یک پیام متنی ارسال کنید.";
                $botInstance->sendMessage($chatId, $text);
            }
        }
        elseif($userStatus && str_contains($userStatus, "blocking_user_description_"))
        {
            $userIdToBlock = str_replace("blocking_user_description_", "", $userStatus);
        
            $normalUserInstance->block_user((int)$userIdToBlock, $message);

            $normalUserInstance->update_user_status($chatId, "idle");
        
            $response = $botInstance->sendMessage($chatId, "در حال مسدود سازی...");
            $responseDecoded = json_decode($response, true);

            $newMessageId = $responseDecoded['result']['message_id'];
        
            $text = "کاربر $userIdToBlock مسدود شد";
            $botInstance->edit_message_text($chatId, (int)$newMessageId, $text, $keyboardInstance->admin_main_menu_keyboard());
        }
        elseif($userStatus == "unblocking_user")
        {
            $idToUnblock = (int)$message;

            if($normalUserInstance->unblock_user($idToUnblock) == false)
            {
                $response = $botInstance->sendMessage($chatId, "در حال بررسی...");
                $responseDecoded = json_decode($response, true);

                $newMessageId = $responseDecoded['result']['message_id'];
        
                $text = "کاربر $idToUnblock مسدود نمیباشد.";
                $botInstance->edit_message_text($chatId, (int)$newMessageId, $text, $keyboardInstance->admin_main_menu_keyboard());
            }
            else
            {
                $normalUserInstance->update_user_status($chatId, "idle");

                $response = $botInstance->sendMessage($chatId, "در حال آزاد سازی...");
                $responseDecoded = json_decode($response, true);

                $newMessageId = $responseDecoded['result']['message_id'];
        
                $text = "مسدودیت کاربر $idToUnblock حذف شد.";
                $botInstance->edit_message_text($chatId, (int)$newMessageId, $text, $keyboardInstance->admin_main_menu_keyboard());
            }
        }
        elseif($userStatus == "direct_message")
        {
            $normalUserInstance->update_user_status($chatId, "typing_message");

            $idToSendMsg = (int)$message;

            $normalUserInstance->save_temp_data($chatId, $idToSendMsg);

            $text = "لطفا پیامی که میخواهید برای کاربر ارسال کنید را بنویسید.";
            $botInstance->sendMessage($chatId, $text);
        }
        elseif($userStatus == "typing_message")
        {
            $normalUserInstance->update_user_status($chatId, "idle");

            $idToSendMsg = $normalUserInstance->get_temp_data($chatId);

            if($idToSendMsg)
            {
                $botInstance->sendMessage($idToSendMsg, $message);

                $response = $botInstance->sendMessage($chatId, "در حال ارسال پیام...");
                $responseDecoded = json_decode($response, true);

                $newMessageId = $responseDecoded['result']['message_id'];

                $text = "پیام با موفقیت برای کاربر $idToSendMsg ارسال شد";
                $botInstance->edit_message_text($chatId, (int)$newMessageId, $text, $keyboardInstance->admin_main_menu_keyboard());

                $normalUserInstance->clear_temp_data($chatId);
            }
            else
            {
                $botInstance->sendMessage($chatId, "خطایی رخ داد: کاربر مقصد یافت نشد.");
            }
        }
        elseif($userStatus == "group_direct_message")
        {
            $normalUserInstance->update_user_status($chatId, "idle");

            $ids = $normalUserInstance->get_all_user_chat_ids();

            $response = $botInstance->sendMessage($chatId, "در حال ارسال پیام...");
            $responseDecoded = json_decode($response, true);

            $newMessageId = $responseDecoded['result']['message_id'];

            foreach($ids as $id)
            {
                if(!in_array($id['user_id'], $admin_chat_ids))
                {
                    $botInstance->sendMessage($id['user_id'], $message);
                }
                
            }

            $text = "پیام شما برای تمام کاربران ارسال شد.";
            $botInstance->edit_message_text($chatId, (int)$newMessageId, $text, $keyboardInstance->admin_main_menu_keyboard());
        }
        elseif($userStatus == "adminChargingWallet")
        {
            $normalUserInstance->update_user_status($chatId, "addingPriceToCharge_$message");

            $userBalance = $normalUserInstance->get_user_balance((int)$message);

            $text = "موجودی فعلی کاربر $message برابر با $userBalance تومان میباشد.\nلطفا مبلغی که قصد شارژ حساب کاربر با آن را دارید را به تومان ارسال کنید.";
            $botInstance->sendMessage($chatId, $text);
        }
        elseif($userStatus && str_contains($userStatus, "addingPriceToCharge_"))
        {
            $normalUserInstance->update_user_status($chatId, "idle");

            $targetUserId = str_replace("addingPriceToCharge_", "", $userStatus);
            $paymentInstance->increase_balance((int)$targetUserId, (float)$message);

            $text = "موجودی کیف پول شما $message تومان توسط ادمین افزایش یافت.";
            $botInstance->sendMessage($targetUserId, $text);

            $response = $botInstance->sendMessage($chatId, "در حال افزایش موجودی...");
            $responseDecoded = json_decode($response, true);

            $newMessageId = $responseDecoded['result']['message_id'];
            $text = "موجود کیف پول کاربر $targetUserId ، $message تومان افزایش یافت";
            $botInstance->edit_message_text($chatId, (int)$newMessageId, $text, $keyboardInstance->admin_main_menu_keyboard());
        }
        elseif($userStatus == "adminDecreaseChargeWallet")
        {

            $userBalance = $normalUserInstance->get_user_balance((int)$message);

            $normalUserInstance->update_user_status($chatId, "decreasingPriceToDeCharge_{$message}_{$userBalance}");

            $text = "موجودی فعلی کاربر $message برابر با $userBalance تومان میباشد.\nلطفا مبلغی که قصد کاهش موجودی حساب کاربر با آن را دارید را به تومان ارسال کنید.";
            $botInstance->sendMessage($chatId, $text);
        }
        elseif($userStatus && str_contains($userStatus, "decreasingPriceToDeCharge_"))
        {
            list($action, $id, $balance) = explode("_", $userStatus);
            
            if($balance - (int)$message < 0)
            {
                $text = "موجودی حساب: $balance \n مبلغ کاهش: $message \n به دلیل منفی شدن موجودی حساب، امکان کاهش موجودی وجود ندارد. \n لطفا مبلغ کمتری ارسال کنید.";
                $botInstance->sendMessage($chatId, $text);
                return;
            }
            else
            {
                $normalUserInstance->update_user_status($chatId, "idle");

                $paymentInstance->decrease_balance((int)$id, (float)$message);

                $text = "موجودی کیف پول شما $message تومان توسط ادمین کاهش یافت.";
                $botInstance->sendMessage($id, $text);

                $response = $botInstance->sendMessage($chatId, "در حال کاهش موجودی...");
                $responseDecoded = json_decode($response, true);

                $newMessageId = $responseDecoded['result']['message_id'];
                $text = "موجود کیف پول کاربر $id ، $message تومان کاهش یافت";
                $botInstance->edit_message_text($chatId, (int)$newMessageId, $text, $keyboardInstance->admin_main_menu_keyboard());
            }
        }
        elseif($userStatus == "showUserInfo")
        {
            $userId = (int)$message;

            $allInfo = $normalUserInstance->get_all_user_info($userId);

            $text = "<b>اطالاعات کاربر $userId</b>\n";
            $text .= "\n";
            
            foreach($allInfo['userBasicInfo'] as $info)
            {
                if($info['username'] == null)
                    $info['username'] = "ندارد";

                $text .= "<b>👤 نام: </b>" . $info['first_name'] . "\n";
                $text .= "<b>🌀 یوزنیم: </b>" . $info['username'] . "\n";
                $text .= "<b>📱 شماره تماس: </b>" . $info['phone_number'] . "\n";
                $text .= "<b>💲 موجودی کیف پول: </b>" . $info['balance'] . "\n";
            }

            $botInstance->sendMessage($chatId, $text);
            
            $purchasesChunks = array_chunk($allInfo['userPurchaseInfo'], 5);

            foreach($purchasesChunks as $chunk)
            {
                $text = "<b>خرید های کاربر $userId</b>\n\n";

                foreach($chunk as $purchase)
                {
                    switch($purchase['status'])
                    {
                        case 'used':
                            $purchase['status'] = "استفاده شده";
                            break;
                        case 'canceled':
                            $purchase['status'] = "لغو شده";
                            break;
                        case 'expired':
                            $purchase['status'] = "منقضی شده";
                            break;
                        case 'wating_for_sms':
                            $purchase['status'] = "در انتظار ارسال پیامک";
                            break;
                        case 'refunded':
                            $purchase['status'] = "برگشت داده شده";
                            break;
                        case 'error':
                            $purchase['status'] = "خطا";
                            break;
                    }

                    $text .= "<b>🔢 شماره: </b>" . $purchase['number'] . "\n";
                    $text .= "<b>🔸 آی دی سفارش: </b>" . $purchase['order_id'] . "\n";
                    $text .= "<b>🌐 کشور: </b>" . $purchase['country'] . "\n";
                    $text .= "<b>📱 سرویس: </b>" . $purchase['service'] . "\n";
                    $text .= "<b>📡 پنل: </b>" . $purchase['pool'] . "\n";
                    $text .= "<b>💲 قیمت(دلار): </b>" . $purchase['cost'] . "\n";
                    $text .= "<b>💲 قیمت(تومان): </b>" . $purchase['price_in_toman'] . "\n";
                    $text .= "<b>🔹 وضعیت: </b>" . $purchase['status'] . "\n";
                    $text .= "<b>📆 تاریخ: </b>" . $purchase['created_at'] . "\n";
                    
                    $text .= "\n";
                    $text .= "💠💠💠💠💠💠💠💠\n";
                    $text .= "\n";
                }

                $botInstance->sendMessage($chatId, $text);
            }

            $text = "گزینه موردنظز خود را انتخاب کنید";
            $botInstance->sendMessage($chatId, $text, $keyboardInstance->admin_main_menu_keyboard());
        }
        elseif($userStatus == "settingBankCard")
        {
            $normalUserInstance->update_user_status($chatId, "adding_bank_card_name");
            
            $normalUserInstance->set_bank_card("card_number", $message);

            $text = "کارت بانکی به نام چه کسی است؟";
            $botInstance->sendMessage($chatId, $text);
        }
        elseif($userStatus == "adding_bank_card_name")
        {
            $normalUserInstance->update_user_status($chatId, "idle");
            
            $normalUserInstance->set_bank_card("name_on_card", $message);

            $response = $botInstance->sendMessage($chatId, "در حال ست کردن کارت بانکی...");
            $responseDecoded = json_decode($response, true);

            $newMessageId = $responseDecoded['result']['message_id'];
            $text = "کارت شما با موفقیت ثبت شد";
            $botInstance->edit_message_text($chatId, (int)$newMessageId, $text, $keyboardInstance->admin_main_menu_keyboard());
        }
    }
    else
    {
        # It's a normal user
        if($normalUserInstance->get_bot_update_situation() == true)
        {
            $photo_path = __DIR__ . "/Assets/img/updating/updating.jpg";
            $caption = "🤖 در حال حاضر ربات در وضعیت به روزرسانی میباشد.\nسپاس از صبر و شکیبایی شما.";
            $botInstance->send_photo($chatId, $photo_path, $caption);
            exit();
        }
        $userState = $normalUserInstance->get_user_state($chatId) ?? null;
        $userStatus = $normalUserInstance->get_user_status($chatId) ?? null;

        if($normalUserInstance->check_user_block_situation($chatId) == true)
        {
            $blockReason = $normalUserInstance->get_block_reason($chatId);

            $text = "شما به دلیل $blockReason مسدود شده اید";

            $botInstance->sendMessage($chatId, $text);

            return;
        }

        if($message == '/start' || $message == '/menu')
        {
            # Add user to db
            if($userState == 0 || $userState == null)
            {
                $normalUserInstance->add_user($content);
                //$normalUserInstance->update_user_state($chatId);
                $phone_numberStatus = $normalUserInstance->get_phone_number_config();

                if($phone_numberStatus == true)
                {
                    $normalUserInstance->update_user_status($chatId, "sharingPhoneNumber");
                    
                    $text = "🔹درود! خوش آمدید، لطفا برای ادامه استفاده از ربات، شماره تماس خود را از طریق دکمه زیر ارسال کنید.";
                    $keyboard = [
                        'keyboard' => [
                            [
                                [
                                    'text' => '📞 ارسال شماره تماس',
                                    'request_contact' => true
                                ]
                            ]
                        ],
                        'resize_keyboard' => true,
                        'one_time_keyboard' => true
                    ];

                    $botInstance->sendMessage($chatId, $text, json_encode($keyboard));
                }
                else
                {
                    if($normalUserInstance->get_bot_user_approvment_situation() == false)
                    {
                        $newUserInfo = $normalUserInstance->get_all_user_info($chatId);

                        $text = "یک کاربر جدید قصد استفاده از خدمات ربات را دارد.\n\n";
                        foreach($newUserInfo['userBasicInfo'] as $info)
                        {
                            if($info['username'] == null)
                                $info['username'] = "ندارد";

                            $text .= "<b>👤 نام: </b>" . "<a href = 'https://t.me/{$info['username']}'>{$info['first_name']}</a>" . "\n";
                            $text .= "<b>🌀 یوزنیم: </b>" . $info['username'] . "\n";
                            $text .= "<b>📱 شماره تماس: </b>" . $info['phone_number'] . "\n";
                        }
                        foreach($admin_chat_ids as $admin_chat_id)
                        {
                            $botInstance->sendMessage($admin_chat_id, $text);
                        }
                        $normalUserInstance->update_user_state($chatId);
                        $text = "درود، خوش آمدید.";
                        $text .= "🔹 لطفا یکی از گزینه های زیر را انتخاب کنید:";
                        # Making main menu inline keyboard
                        $keyboardInstance->addInlineButton("🔢 خرید سرویس", "buyServiceBtn", null, 0);
                        $keyboardInstance->addInlineButton("➕ شارژ کیف پول", "chargeWalletBtn", null, 1);
                        $keyboardInstance->addInlineButton("💳 موجودی", "balanceBtn", null, 1);
                        $keyboardInstance->addInlineButton("🛒 خرید های من", "myOrdersBtn", null, 2);
                        $keyboardInstance->addInlineButton("👨‍💻 ارتباط با پشتیبانی", null, "https://t.me/asus1900", 3);
                        $mainMenuKeyboard = $keyboardInstance->getInlineKeyboard();
                        $botInstance->sendMessage($chatId, $text, $mainMenuKeyboard);
                    }
                    else
                    {
                        $normalUserInstance->update_user_status($chatId, "watingForApprove");
        
                        $text = "سلام دوست من\nبرای استفاده از خدمات ربات نیاز به تایید اکانت توسط ادمین دارید،به محض تایید شدن نتیجه به شما اعلام میگردد.\nممنون از صبر و شکیبایی شما";
                        $botInstance->sendMessage($chatId, $text);

                        $newUserInfo = $normalUserInstance->get_all_user_info($chatId);
            
                        $text = "یک کاربر جدید قصد استفاده از خدمات ربات را دارد.\n\n";
                        foreach($newUserInfo['userBasicInfo'] as $info)
                        {
                            if($info['username'] == null)
                                $info['username'] = "ندارد";
            
                            $text .= "<b>👤 نام: </b>" . "<a href = 'https://t.me/{$info['username']}'>{$info['first_name']}</a>" . "\n";
                            $text .= "<b>🔢 آی دی عددی: </b>" . $info['user_id'] . "\n";
                            $text .= "<b>🌀 یوزنیم: </b>" . $info['username'] . "\n";
                            $text .= "<b>📱 شماره تماس: </b>" . $info['phone_number'] . "\n";
                        }
            
                        $keyboardInstance->addInlineButton("✅", "approveUser_$chatId", null, 0);
                        $keyboardInstance->addInlineButton("❌", "dontApproveUser_$chatId", null, 0);
                        $approveUserOrNot = $keyboardInstance->getInlineKeyboard();
            
                        foreach($admin_chat_ids as $admin_chat_id)
                        {
                            $botInstance->sendMessage($admin_chat_id, $text, $approveUserOrNot);
                        }
                    }
                }
            }
            elseif($userState == 1)
            {
                $text = "🔹 لطفا یکی از گزینه های زیر را انتخاب کنید:";
                # Making main menu inline keyboard
                $keyboardInstance->addInlineButton("🔢 خرید سرویس", "buyServiceBtn", null, 0);
                $keyboardInstance->addInlineButton("➕ شارژ کیف پول", "chargeWalletBtn", null, 1);
                $keyboardInstance->addInlineButton("💳 موجودی", "balanceBtn", null, 1);
                $keyboardInstance->addInlineButton("🛒 خرید های من", "myOrdersBtn", null, 2);
                $keyboardInstance->addInlineButton("👨‍💻 ارتباط با پشتیبانی", null, "https://t.me/asus1900", 3);
                $mainMenuKeyboard = $keyboardInstance->getInlineKeyboard();
                $botInstance->sendMessage($chatId, $text, $mainMenuKeyboard);
            }
        }
        elseif($userStatus == "sharingPhoneNumber")
        {
            $normalUserInstance->save_phone_number($chatId, $phoneNumber);

            //$normalUserInstance->update_user_state($chatId);
            $normalUserInstance->update_user_status($chatId, "watingForApprove");

            if($normalUserInstance->get_bot_user_approvment_situation() == true)
            {
                $text = "شماره شما با موفقیت ثبت شد. پس از تایید حساب شما توسط ادمین میتوانید از خدمات ربات استفاده کنید.";
                $removeKeyboard = ['remove_keyboard' => true];
                $botInstance->sendMessage($chatId, $text, json_encode($removeKeyboard));

                $newUserInfo = $normalUserInstance->get_all_user_info($chatId);

                $text = "یک کاربر جدید قصد استفاده از خدمات ربات را دارد.\n\n";
                foreach($newUserInfo['userBasicInfo'] as $info)
                {
                    if($info['username'] == null)
                        $info['username'] = "ندارد";

                    $text .= "<b>👤 نام: </b>" . "<a href = 'https://t.me/{$info['username']}'>{$info['first_name']}</a>" . "\n";
                    $text .= "<b>🌀 یوزنیم: </b>" . $info['username'] . "\n";
                    $text .= "<b>📱 شماره تماس: </b>" . $info['phone_number'] . "\n";
                }

                $keyboardInstance->addInlineButton("✅", "approveUser_$chatId", null, 0);
                $keyboardInstance->addInlineButton("❌", "dontApproveUser_$chatId", null, 0);
                $approveUserOrNot = $keyboardInstance->getInlineKeyboard();

                foreach($admin_chat_ids as $admin_chat_id)
                {
                    $botInstance->sendMessage($admin_chat_id, $text, $approveUserOrNot);
                }
            }
            else
            {
                $newUserInfo = $normalUserInstance->get_all_user_info($chatId);

                $text = "یک کاربر جدید قصد استفاده از خدمات ربات را دارد.\n\n";
                foreach($newUserInfo['userBasicInfo'] as $info)
                {
                    if($info['username'] == null)
                        $info['username'] = "ندارد";

                    $text .= "<b>👤 نام: </b>" . "<a href = 'https://t.me/{$info['username']}'>{$info['first_name']}</a>" . "\n";
                    $text .= "<b>🌀 یوزنیم: </b>" . $info['username'] . "\n";
                    $text .= "<b>📱 شماره تماس: </b>" . $info['phone_number'] . "\n";
                }
                foreach($admin_chat_ids as $admin_chat_id)
                {
                    $botInstance->sendMessage($admin_chat_id, $text);
                }

                $normalUserInstance->update_user_state($chatId);
                $text = "🔹 لطفا یکی از گزینه های زیر را انتخاب کنید:";
                # Making main menu inline keyboard
                $keyboardInstance->addInlineButton("🔢 خرید سرویس", "buyServiceBtn", null, 0);
                $keyboardInstance->addInlineButton("➕ شارژ کیف پول", "chargeWalletBtn", null, 1);
                $keyboardInstance->addInlineButton("💳 موجودی", "balanceBtn", null, 1);
                $keyboardInstance->addInlineButton("🛒 خرید های من", "myOrdersBtn", null, 2);
                $keyboardInstance->addInlineButton("👨‍💻 ارتباط با پشتیبانی", null, "https://t.me/asus1900", 3);
                $mainMenuKeyboard = $keyboardInstance->getInlineKeyboard();
                $botInstance->sendMessage($chatId, $text, $mainMenuKeyboard);
            }
        }
        elseif($userStatus == "adding_price")
        {
            $userAmount = floatval($message);
            if(floatval($message))
            {
                $amount = $message;

                if($amount >= 5000)
                {
                    $cardDetails = $normalUserInstance->get_bank_card();
                    $paymentInstance->add_transaction($chatId, "credit", $amount, "pending");
                    $normalUserInstance->update_user_status($chatId, "sending_receipt");
                    
                    $keyboardInstance->addInlineButton("❌ لغو تراکنش", "cancelPayBtn", null, 0);
                    $cancelPayBtn = $keyboardInstance->getInlineKeyboard();
                    $botInstance->sendMessage($chatId, "مبلغ شما در انتظار تایید پرداخت میباشد.
                    \nلطفا مبلغ مورد نظر را به شماره کارت:\n {$cardDetails['card_number']} \n به نام: {$cardDetails['name_on_card']} \n  وازیر کنید و رسید پرداختی را در همین چت ارسال کنید.\nبعد از تایید مبلغ مورد نظر به کیف پول شما افزوده میشود.", $cancelPayBtn);
                }
                else
                {
                    $botInstance->sendMessage($chatId, "مبلغ تراکنش نمیتواند کمتر از 5000 تومان باشد.");
                }
            }
            else
            {
                $botInstance->sendMessage($chatId, "لطفا مبلغ مورد نظر را بصورت عددی وارد کنید.");
            }
        }
        elseif($userStatus == "sending_receipt")
        {
            if(isset($content["message"]["photo"]))
            {
                # Getting photo id
                $photoArray = $content["message"]["photo"];
                $photoFileId = end($photoArray)["file_id"];

                # Getting user info to put in photo caption
                $amountInQueue = $paymentInstance->get_user_last_transaction_amount($chatId);
                $amountInQueue = number_format($amountInQueue['amount'], 0, '.', ",");
                $userTransactionId = $paymentInstance->get_user_last_transaction_id($chatId);
                $userInfo = $normalUserInstance->get_user_info($chatId);
                $username = ($userInfo["username"]) ? $userInfo["username"] : $userInfo["user_id"];
                
                if($userInfo['username'] == null)
                {
                    $text2 = "این کاربر یوزرنیم ندارد";
                }
                else
                {
                    $text2 = "<a href = 'https://t.me/{$userInfo['username']}'>مشاهده کاربر </a>";
                }

                $caption = "رسید پرداخت از {$userInfo['first_name']}\nآی دی عددی: {$userInfo['user_id']} \nمبلغ: $amountInQueue تومان\nشناسه پرداخت: {$userTransactionId['id']}-{$chatId}";

                $keyboardInstance->addInlineButton("✅", "acceptTransaction_{$userTransactionId['id']}",null);
                $keyboardInstance->addInlineButton("❌", "rejectTransaction_{$userTransactionId['id']}",null);
                $confirmBtn = $keyboardInstance->getInlineKeyboard();
                # Sending photo to all admins
                foreach($admin_chat_ids as $admin_chat_id)
                {
                    $botInstance->send_photo_to_admins($admin_chat_id, $photoFileId, $caption, $confirmBtn);
                    $botInstance->sendMessage($admin_chat_id,$text2);
                }

                $keyboardInstance->clearInlineButtons();

                $normalUserInstance->update_user_status($chatId, "idle");

                $keyboardInstance->addInlineButton("🔢 خرید سرویس", "buyServiceBtn", null, 0);
                $keyboardInstance->addInlineButton("➕ شارژ کیف پول", "chargeWalletBtn", null, 1);
                $keyboardInstance->addInlineButton("💳 موجودی", "balanceBtn", null, 1);
                $keyboardInstance->addInlineButton("🛒 خرید های من", "myOrdersBtn", null, 2);
                $keyboardInstance->addInlineButton("👨‍💻 ارتباط با پشتیبانی", null, "https://t.me/asus1900", 3);
                $mainMenuKeyboardAfterPay = $keyboardInstance->getInlineKeyboard();
                
                $botInstance->sendMessage($chatId, "رسید پرداختی شما با شناسه {$userTransactionId['id']}-{$chatId} ثبت شد. مبلغ پس از تایید، به کیف پول شما افزوده میشود.", $mainMenuKeyboardAfterPay);
            }
            else
            {
                $botInstance->sendMessage($chatId, "لطفا عکس رسید پرداختی را ارسال کنید.");
            }
        }
    }

}
elseif (isset($content['callback_query']))
{
    $callbackQuery = $content['callback_query'];
    $callbackData = $callbackQuery['data'] ?? null;
    $chatId = $callbackQuery['message']['chat']['id'] ?? null;
    $messageId = $callbackQuery['message']['message_id'] ?? null;

    if (!$chatId || !$messageId)
    {
        $botInstance->sendMessage($chatId, 'خطا: اطلاعات کافی دریافت نشد.');
        return;
    }

    if($callbackData == "buyServiceBtn")
    {
        
        $keyboardInstance->addInlineButton("تلگرام", "telegramBtn", null, 0);
        $keyboardInstance->addInlineButton("واتس‌اپ", "whatsappBtn", null, 0);
        $keyboardInstance->addInlineButton("اینستاگرام", "instaBtn", null, 1);
        $keyboardInstance->addInlineButton("اپل", "appleBtn", null, 1);
        $keyboardInstance->addInlineButton("متفرقه", "othersBtn", null, 2);
        $keyboardInstance->addInlineButton("🔙 برگشت", "backToMainMenuBtn", null, 3);
        $serviceKeyboard = $keyboardInstance->getInlineKeyboard();
        $botInstance->edit_message_text($chatId, $messageId, "🔸 لطفا سرویس مورد نظر خود را انتخاب کنید:", $serviceKeyboard);
    }
    elseif($callbackData == "balanceBtn")
    {
        $balance = $normalUserInstance->get_user_balance($chatId);
        $balance = number_format($balance, 0, '.', ',');

        $keyboardInstance->addInlineButton("➕ شارژ کیف پول", "chargeWalletBtn", null, 0);
        $keyboardInstance->addInlineButton("🔙 برگشت", "backToMainMenuBtn", null, 1);
        $balanceBtn = $keyboardInstance->getInlineKeyboard();
        $botInstance->edit_message_text($chatId, $messageId, "💲 موجود کیف پول: $balance تومان", $balanceBtn);
    }
    elseif($callbackData == "chargeWalletBtn")
    {
        $normalUserInstance->update_user_status($chatId, "adding_price");

        $keyboardInstance->addInlineButton("🔙 برگشت", "backToMainMenuFromWalletBtn", null);
        $backToMainMenuFromWallet = $keyboardInstance->getInlineKeyboard();
        $botInstance->edit_message_text($chatId, $messageId, "لطفا مقدار مبلغی که میخواهید با آن کیف پولتان را شارژ کنید به تومان ارسال کنید.", $backToMainMenuFromWallet);
    }
    elseif($callbackData == "backToMainMenuFromWalletBtn")
    {
        $normalUserInstance->update_user_status($chatId, "idle");

        $keyboardInstance->addInlineButton("🔢 خرید سرویس", "buyServiceBtn", null, 0);
        $keyboardInstance->addInlineButton("➕ شارژ کیف پول", "chargeWalletBtn", null, 1);
        $keyboardInstance->addInlineButton("💳 موجودی", "balanceBtn", null, 1);
        $keyboardInstance->addInlineButton("🛒 خرید های من", "myOrdersBtn", null, 2);
        $keyboardInstance->addInlineButton("👨‍💻 ارتباط با پشتیبانی", null, "https://t.me/asus1900", 3);
        $mainMenuKeyboard = $keyboardInstance->getInlineKeyboard();
        //$botInstance->sendMessage($chatId, $text, $mainMenuKeyboard);
        $botInstance->edit_message_text($chatId, $messageId, "🔹 لطفا یکی از گزینه های زیر را انتخاب کنید:", $mainMenuKeyboard);
    }
    elseif($callbackData == "backToMainMenuBtn")
    {
        $keyboardInstance->addInlineButton("🔢 خرید سرویس", "buyServiceBtn", null, 0);
        $keyboardInstance->addInlineButton("➕ شارژ کیف پول", "chargeWalletBtn", null, 1);
        $keyboardInstance->addInlineButton("💳 موجودی", "balanceBtn", null, 1);
        $keyboardInstance->addInlineButton("🛒 خرید های من", "myOrdersBtn", null, 2);
        $keyboardInstance->addInlineButton("👨‍💻 ارتباط با پشتیبانی", null, "https://t.me/asus1900", 3);
        $mainMenuKeyboard = $keyboardInstance->getInlineKeyboard();
        //$botInstance->sendMessage($chatId, $text, $mainMenuKeyboard);
        $botInstance->edit_message_text($chatId, $messageId, "🔹 لطفا یکی از گزینه های زیر را انتخاب کنید:", $mainMenuKeyboard);
    }
    elseif($callbackData == "cancelPayBtn")
    {
        $normalUserInstance->update_user_status($chatId, "idle");
        $paymentInstance->update_transaction($chatId, "rejected_by_user");

        $keyboardInstance->addInlineButton("🔢 خرید سرویس", "buyServiceBtn", null, 0);
        $keyboardInstance->addInlineButton("➕ شارژ کیف پول", "chargeWalletBtn", null, 1);
        $keyboardInstance->addInlineButton("💳 موجودی", "balanceBtn", null, 1);
        $keyboardInstance->addInlineButton("🛒 خرید های من", "myOrdersBtn", null, 2);
        $keyboardInstance->addInlineButton("👨‍💻 ارتباط با پشتیبانی", null, "https://t.me/asus1900", 3);
        $mainMenuKeyboard = $keyboardInstance->getInlineKeyboard();
        //$botInstance->sendMessage($chatId, $text, $mainMenuKeyboard);
        $botInstance->edit_message_text($chatId, $messageId, "🔹 تراکنش شما لغو گردید.\nلطفا یکی از گزینه های زیر را انتخاب کنید:", $mainMenuKeyboard);
    }
    elseif(strpos($callbackData, 'acceptTransaction_') !== false)
    {
        $transactionId = str_replace('acceptTransaction_', '', $callbackData);
        $paymentInstance->update_transaction_status($transactionId, 'approved');

        $botInstance->delete_message($chatId, $messageId);
        $botInstance->sendMessage($chatId, "تراکنش با شناسه $transactionId تایید شد.");

        $amountToAdd = $paymentInstance->get_transacton_by_id($transactionId);
        $paymentInstance->increase_balance($amountToAdd['user_id'], $amountToAdd['amount']);

        $formattedAmountToAdd = number_format($amountToAdd['amount'], 0, '.', ',');
        $botInstance->sendMessage($amountToAdd['user_id'], "مبلغ $formattedAmountToAdd به کیف پول شما افزوده شد.\nسپاس از همراهی شما.");
    }
    elseif(strpos($callbackData, 'rejectTransaction_') !== false)
    {
        $transactionId = str_replace('rejectTransaction_', '', $callbackData);
        $amountToAdd = $paymentInstance->get_transacton_by_id($transactionId);
        $paymentInstance->update_transaction_status($transactionId, 'rejected');
        $botInstance->delete_message($chatId, $messageId);
        $botInstance->sendMessage($chatId, "تراکنش با شناسه $transactionId رد شد.");
        $botInstance->sendMessage($amountToAdd['user_id'], "تراکنش با شناسه $transactionId رد شد.");
    }
    elseif($callbackData == "telegramBtn")
    {
        $countriesList = $countryListInstance->get_countries_by_service("Telegram");
        $itemsPerPage = 20;
        $chunks = array_chunk($countriesList, $itemsPerPage);
        $currentPage = 0;
        
        $countryListInstance->countries_pagination($currentPage, $chunks, $botInstance, $keyboardInstance, $chatId);

        $botInstance->edit_message_text($chatId, $messageId, "کشور موردنظر خود را انتخاب کنید");
    }
    elseif($callbackData && str_contains($callbackData, "telegramBtn_page_"))
    {
        $currentPage = (int)str_replace("telegramBtn_page_", "", $callbackData);
        
        $countriesList = $countryListInstance->get_countries_by_service("Telegram");
        $itemsPerPage = 20;
        
        $chunks = array_chunk($countriesList, $itemsPerPage);
        
        $countryListInstance->countries_pagination($currentPage, $chunks, $botInstance, $keyboardInstance, $chatId, $messageId);
    }
    elseif($callbackData == "whatsappBtn")
    {
        $countriesList = $countryListInstance->get_countries_by_service("WhatsApp");
        $itemsPerPage = 20;
        $chunks = array_chunk($countriesList, $itemsPerPage);
        $currentPage = 0;
        
        $countryListInstance->countries_paginationw($currentPage, $chunks, $botInstance, $keyboardInstance, $chatId);
    }
    elseif($callbackData && str_contains($callbackData, "waBtn_page_"))
    {
        $currentPage = (int)str_replace("waBtn_page_", "", $callbackData);
        
        $countriesList = $countryListInstance->get_countries_by_service("WhatsApp");
        $itemsPerPage = 20;
        
        $chunks = array_chunk($countriesList, $itemsPerPage);
        
        $countryListInstance->countries_paginationw($currentPage, $chunks, $botInstance, $keyboardInstance, $chatId, $messageId);
    }
    elseif($callbackData == "instaBtn")
    {
        $countriesList = $countryListInstance->get_countries_by_service("Instagram");
        $itemsPerPage = 20;
        $chunks = array_chunk($countriesList, $itemsPerPage);
        $currentPage = 0;
        
        $countryListInstance->countries_paginationig($currentPage, $chunks, $botInstance, $keyboardInstance, $chatId);
    }
    elseif($callbackData && str_contains($callbackData, "igBtn_page_"))
    {
        $currentPage = (int)str_replace("igBtn_page_", "", $callbackData);
        
        $countriesList = $countryListInstance->get_countries_by_service("Instagram");
        $itemsPerPage = 20;
        
        $chunks = array_chunk($countriesList, $itemsPerPage);
        
        $countryListInstance->countries_paginationig($currentPage, $chunks, $botInstance, $keyboardInstance, $chatId, $messageId);
    }
    elseif($callbackData == "appleBtn")
    {
        $countriesList = $countryListInstance->get_countries_by_service("Apple");
        $itemsPerPage = 20;
        $chunks = array_chunk($countriesList, $itemsPerPage);
        $currentPage = 0;
        
        $countryListInstance->countries_paginationapple($currentPage, $chunks, $botInstance, $keyboardInstance, $chatId);
    }
    elseif($callbackData && str_contains($callbackData, "appleBtn_page_"))
    {
        $currentPage = (int)str_replace("appleBtn_page_", "", $callbackData);
        
        $countriesList = $countryListInstance->get_countries_by_service("Apple");
        $itemsPerPage = 20;
        
        $chunks = array_chunk($countriesList, $itemsPerPage);
        
        $countryListInstance->countries_paginationapple($currentPage, $chunks, $botInstance, $keyboardInstance, $chatId, $messageId);
    }//1111111111111111111111111111111111111111111111111111111111
    elseif($callbackData && str_contains($callbackData, "tgBtn_"))
    {
        $text = "لطفا صبر کنید...";
        $response = $botInstance->sendMessage($chatId, $text);

        $responseDecoded = json_decode($response, true);
        $newMessageId = $responseDecoded['result']['message_id'];

        $poolList = $poolListInstance->extract_id_from_pool_list();
        $requestedCountryName = urldecode(str_replace('tgBtn_', '', $callbackData));
        $serviceName = "Telegram";
        $priceFromPools = $countryPriceInstance->get_prices($requestedCountryName, $serviceName, $poolList);

        $row = 0;
        $keyboardInstance->addInlineButton("📱 نام سرویس: $serviceName", "nonFunctional", null, $row);
        $row++;

        if($priceInstance->is_it_time_to_refresh_price(time()))
        {
            $USDT_Price = Util::get_USDT();

            if($USDT_Price !== null)
            {
                $priceInstance->refresh_price($USDT_Price);
            }
        }
        $USDT = $priceInstance->get_price();
        $profit = $priceInstance->get_profit();

        foreach($priceFromPools as $priceFromPool)
        {
            $tomanPricee = $USDT * $priceFromPool['price'] + $profit;
            $tomanPrice = ceil($tomanPricee / 1000) * 1000;
            $tomanPriceToShow = number_format($tomanPrice, 0);

            $keyboardInstance->addInlineButton("💲 قیمت: $tomanPriceToShow تومان", "nonFunctional", null, $row);
            $keyboardInstance->addInlineButton("📡 پنل: {$priceFromPool['pool']}", "tgPanel_{$priceFromPool['pool']}_{$priceFromPool['success_rate']}_{$tomanPrice}_$requestedCountryName", null, $row);
            $row++;
        }

        $keyboardInstance->addInlineButton("🔙 برگشت به لیست کشور ها", "back_to_tg_countries", null, $row);

        $tgNumbersBtn = $keyboardInstance->getInlineKeyboard();
        $botInstance->edit_message_text($chatId, (int)$newMessageId, "لطفا یکی از پنل ها را انتخاب کنید:", $tgNumbersBtn);
    }
    elseif($callbackData && str_contains($callbackData, "tgPanel_"))
    {
        list($action, $poolId, $success_rate, $tomanPrice, $requestedCountryName) = explode('_', $callbackData);
        $serviceName = "Telegram";

        $formatted_message = "📱 <b>سرویس</b> $serviceName\n";
        $formatted_message .= "🌐 <b>کشور: </b> $requestedCountryName\n";
        $formatted_message .= "📡 <b>پنل: </b> $poolId\n";
        $formatted_message .= "💲 <b>قیمت</b> $tomanPrice تومان\n";
        $formatted_message .= "💯 <b>درصد موفقیت:</b>$success_rate\n";

        $keyboardInstance->addInlineButton("💳 پرداخت", "buyTg_{$serviceName}_{$requestedCountryName}_{$poolId}_{$tomanPrice}_{$success_rate}", null);
        $keyboardInstance->addInlineButton("🔙 برگشت به لیست کشور ها", "back_to_tg_countries", null);

        $buyInlineBtn = $keyboardInstance->getInlineKeyboard();

        $botInstance->edit_message_text($chatId, $messageId, $formatted_message, $buyInlineBtn);
        //$botInstance->sendMessage($chatId, $formatted_message, $buyInlineBtn);
    }
    elseif($callbackData && str_contains($callbackData, "buyTg_"))
    {
        list($action, $serviceName, $requestedCountryName, $poolId, $price, $success_rate) = explode('_', $callbackData);

        $text = "چند لحظه صبر کنید...";
        $response = $botInstance->sendMessage($chatId, $text);

        $responseDecoded = json_decode($response, true);
        $newMessageId = $responseDecoded['result']['message_id'];
        
        $userBalance = $normalUserInstance->get_user_balance($chatId);
        
        if($userBalance - $price < 0)
        {
            $text = "موجودی کیف پول شما برای خرید این شماره کافی نیست.\n لطفا از طریق منو کیف پول خود را شارژ کنید.";
            $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
            exit();
        }
        
        $buyNumberResult = $buyNumberInstance->buy_number($requestedCountryName, $serviceName, $poolId);
        
        if($buyNumberResult["success"] == 1)
        {
            $paymentInstance->decrease_balance($chatId, $price);
            
            $phone_number = $buyNumberResult['number'];
            $order_id = $buyNumberResult['order_id'];
            $orderid = $buyNumberResult['orderid'];
            $country = $buyNumberResult['country'];
            $service = $buyNumberResult['service'];
            $pool = $buyNumberResult['pool'];
            $expires_in = $buyNumberResult['expires_in'] / 60;
            $cost = $buyNumberResult['cost'];
            
            $text = "درخواست شما با موفقیت ثبت شد:\n 🔢 شماره: `$phone_number`\n⏰ زمان انقضا: $expires_in دقیقه\n\n❗لطفا شماره خریداری شده را در برنامه موردنظر وارد کنید، سپس به ربات بازگشته و یک مرتبه بر روی دکمه دریافت SMS کلیک کنید. \nمنتظر دریافت کد ورود بمانید.\n به محض ارسال SMS ورود، کد توسط ربات برای شما ارسال خواهد شد.";
            $keyboardInstance->addInlineButton("❌ لغو شماره", "tgSMSCancelBtn_{$orderid}_{$price}_{$phone_number}_{$expires_in}", null, 0);
            $keyboardInstance->addInlineButton("📲 دریافت SMS", "tgSMSBtn_{$orderid}", null, 0);
            $tgReceiveSms = $keyboardInstance->getInlineKeyboard();
            $botInstance->edit_message_text($chatId, (int)$newMessageId, $text, $tgReceiveSms, "Markdown");
            $userPurchaseInstance->add_user_purchase($chatId, $phone_number, $orderid, $country, $service, $pool, $cost, $price);
        }
        elseif($buyNumberResult["success"] == 0)
        {
            switch($buyNumberResult["type"])
            {
                case "ORDER_FAILED":
                    $text = "مشکلی پیش آمده لطفا با شماره ای دیگر تلاش کنید.";
                    $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
                    break;
                
                case "OUT_OF_STOCK":
                    $text = "متاسفانه شماره‌ای موجود نیست";
                    $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
                    break;
                
                case "PRICE_NOT_FOUND":
                    $text = "ما نتوانستیم پنلی مناسب با قیمت مورد نظر پیدا کنیم. لطفا مجددا تلاش کنید.";
                    $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
                    break;
                
                case "BALANCE_ERROR":
                    for($i = 0; $i < count($admin_chat_ids); $i++)
                    {
                        $botInstance->sendMessage($admin_chat_ids[$i], "موجودی شما کافی نیست. لطفا حساب خود را شارژ کنید.");
                    }
                    $text = "خطا در درخواست.لطفا پس از چند دقیقه مجددا درخواست خود را ارسال کنید.";
                    $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
                    break;
                
                default:
                    $text = "خطای نامشخص";
                    $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
                    break;
            }
        }
        else
        {
            $text = "وضعیت نامشخص. لطفا مجددا تلاش کنید.";
            $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
        }
    }
    elseif($callbackData == "back_to_tg_countries")
    {
        $countriesList = $countryListInstance->get_countries_by_service("Telegram");
        $itemsPerPage = 20;
        $chunks = array_chunk($countriesList, $itemsPerPage);
        $currentPage = 0;
        
        $countryListInstance->countries_pagination($currentPage, $chunks, $botInstance, $keyboardInstance, $chatId);
        $botInstance->edit_message_text($chatId, $messageId, "به لیست کشور های تلگرام بازگشتید");
        $botInstance->delete_message($chatId, $messageId);
    }//222222222222222222222222222222222222
    elseif($callbackData && str_contains($callbackData, "waBtn_"))
    {
        $text = "لطفا صبر کنید...";
        $response = $botInstance->sendMessage($chatId, $text);

        $responseDecoded = json_decode($response, true);
        $newMessageId = $responseDecoded['result']['message_id'];
        
        $poolList = $poolListInstance->extract_id_from_pool_list();
        $requestedCountryName = urldecode(str_replace('waBtn_', '', $callbackData));
        $serviceName = "WhatsApp";
        $priceFromPools = $countryPriceInstance->get_prices($requestedCountryName, $serviceName, $poolList);

        $row = 0;
        $keyboardInstance->addInlineButton("📱 نام سرویس: $serviceName", "nonFunctional", null, $row);
        $row++;

        if($priceInstance->is_it_time_to_refresh_price(time()))
        {
            $USDT_Price = Util::get_USDT();

            if($USDT_Price !== null)
            {
                $priceInstance->refresh_price($USDT_Price);
            }
        }
        $USDT = $priceInstance->get_price();
        $profit = $priceInstance->get_profit();

        foreach($priceFromPools as $priceFromPool)
        {
            $tomanPricee = $USDT * $priceFromPool['price'] + $profit;
            $tomanPrice = ceil($tomanPricee / 1000) * 1000;
            $tomanPriceToShow = number_format($tomanPrice, 0);

            $keyboardInstance->addInlineButton("💲 قیمت: $tomanPriceToShow", "nonFunctional", null, $row);
            $keyboardInstance->addInlineButton("📡 پنل: {$priceFromPool['pool']}", "waPanel_{$priceFromPool['pool']}_{$priceFromPool['success_rate']}_{$tomanPrice}_$requestedCountryName", null, $row);
            $row++;
        }

        $keyboardInstance->addInlineButton("🔙 برگشت به لیست کشور ها", "back_to_wa_countries", null, $row);
        
        $tgNumbersBtn = $keyboardInstance->getInlineKeyboard();
        $botInstance->edit_message_text($chatId, (int)$newMessageId, "لطفا یکی از پنل ها را انتخاب کنید:", $tgNumbersBtn);
    }
    elseif($callbackData && str_contains($callbackData, "waPanel_"))
    {
        list($action, $poolId, $success_rate, $tomanPrice, $requestedCountryName) = explode('_', $callbackData);
        $serviceName = "WhatsApp";

        $formatted_message = "📱 <b>سرویس</b> $serviceName\n";
        $formatted_message .= "🌐 <b>کشور: </b> $requestedCountryName\n";
        $formatted_message .= "📡 <b>پنل: </b> $poolId\n";
        $formatted_message .= "💲 <b>قیمت</b> $tomanPrice تومان\n";
        $formatted_message .= "💯 <b>درصد موفقیت:</b>$success_rate\n";

        $keyboardInstance->addInlineButton("💳 پرداخت", "buyWg_{$serviceName}_{$requestedCountryName}_{$poolId}_{$tomanPrice}_{$success_rate}", null);
        $keyboardInstance->addInlineButton("🔙 برگشت به لیست کشور ها", "back_to_wa_countries", null);

        $buyInlineBtn = $keyboardInstance->getInlineKeyboard();

        $botInstance->edit_message_text($chatId, $messageId, $formatted_message, $buyInlineBtn);
        //$botInstance->sendMessage($chatId, $formatted_message, $buyInlineBtn);
    }
    elseif($callbackData && str_contains($callbackData, "buyWg_"))
    {
        list($action, $serviceName, $requestedCountryName, $poolId, $price, $success_rate) = explode('_', $callbackData);
        
        $text = "چند لحظه صبر کنید...";
        $response = $botInstance->sendMessage($chatId, $text);
        
        $responseDecoded = json_decode($response, true);
        $newMessageId = $responseDecoded['result']['message_id'];  

        $userBalance = $normalUserInstance->get_user_balance($chatId);
        
        if($userBalance - $price < 0)
        {
            $text = "موجودی کیف پول شما برای خرید این شماره کافی نیست.\n لطفا از طریق منو کیف پول خود را شارژ کنید.";
            $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
            exit();
        }
        
        $buyNumberResult = $buyNumberInstance->buy_number($requestedCountryName, $serviceName, $poolId);
        
        if($buyNumberResult["success"] == 1)
        {
            $paymentInstance->decrease_balance($chatId, $price);
            
            $phone_number = $buyNumberResult['number'];
            $order_id = $buyNumberResult['order_id'];
            $orderid = $buyNumberResult['orderid'];
            $country = $buyNumberResult['country'];
            $service = $buyNumberResult['service'];
            $pool = $buyNumberResult['pool'];
            $expires_in = $buyNumberResult['expires_in'] / 60;
            $cost = $buyNumberResult['cost'];

            $text = "درخواست شما با موفقیت ثبت شد:\n 🔢 شماره: `$phone_number` \n⏰ زمان انقضا: $expires_in دقیقه\n\n❗لطفا شماره خریداری شده را در برنامه موردنظر وارد کنید، سپس به ربات بازگشته و یک مرتبه بر روی دکمه دریافت SMS کلیک کنید. \nمنتظر دریافت کد ورود بمانید.\n به محض ارسال SMS ورود، کد توسط ربات برای شما ارسال خواهد شد.";
            $keyboardInstance->addInlineButton("❌ لغو شماره", "waSMSCancelBtn_{$orderid}_{$price}_{$phone_number}_{$expires_in}", null, 0);
            $keyboardInstance->addInlineButton("📲 دریافت SMS", "waSMSBtn_{$orderid}", null, 0);
            $tgReceiveSms = $keyboardInstance->getInlineKeyboard();
            $botInstance->edit_message_text($chatId, (int)$newMessageId, $text, $tgReceiveSms, "Markdown");
            $userPurchaseInstance->add_user_purchase($chatId, $phone_number, $orderid, $country, $service, $pool, $cost, $price);
        }
        elseif($buyNumberResult["success"] == 0)
        {
            switch($buyNumberResult["type"])
            {
                case "ORDER_FAILED":
                    $text = "مشکلی پیش آمده لطفا با شماره ای دیگر تلاش کنید.";
                    $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
                    break;
                
                case "OUT_OF_STOCK":
                    $text = "متاسفانه شماره‌ای موجود نیست";
                    $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
                    break;
                
                case "PRICE_NOT_FOUND":
                    $text = "ما نتوانستیم پنلی مناسب با قیمت مورد نظر پیدا کنیم. لطفا مجددا تلاش کنید.";
                    $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
                    break;
                
                case "BALANCE_ERROR":
                    for($i = 0; $i < count($admin_chat_ids); $i++)
                    {
                        $botInstance->sendMessage($admin_chat_ids[$i], "موجودی شما کافی نیست. لطفا حساب خود را شارژ کنید.");
                    }
                    $text = "خطا در درخواست.لطفا پس از چند دقیقه مجددا درخواست خود را ارسال کنید.";
                    $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
                    break;
                
                default:
                    $text = "خطای نامشخص";
                    $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
                    break;
            }
        }
        else
        {
            $text = "وضعیت نامشخص. لطفا مجددا تلاش کنید.";
            $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
        }
    }

    elseif($callbackData == "back_to_wa_countries")
    {
        $countriesList = $countryListInstance->get_countries_by_service("WhatsApp");
        $itemsPerPage = 20;
        $chunks = array_chunk($countriesList, $itemsPerPage);
        $currentPage = 0;
        
        $countryListInstance->countries_paginationw($currentPage, $chunks, $botInstance, $keyboardInstance, $chatId);
        $botInstance->edit_message_text($chatId, $messageId, "به لیست کشور های واتس اپ بازگشتید");
        //$botInstance->delete_message($chatId, $messageId);
    }
    elseif($callbackData == "back_to_ig_countries")
    {
        $countriesList = $countryListInstance->get_countries_by_service("Instagram");
        $itemsPerPage = 20;
        $chunks = array_chunk($countriesList, $itemsPerPage);
        $currentPage = 0;
        
        $countryListInstance->countries_paginationig($currentPage, $chunks, $botInstance, $keyboardInstance, $chatId);
        $botInstance->edit_message_text($chatId, $messageId, "به لیست کشور های اینستاگرام بازگشتید");
        //$botInstance->delete_message($chatId, $messageId);
    }
    elseif($callbackData == "back_to_apple_countries")
    {
        $countriesList = $countryListInstance->get_countries_by_service("Apple");
        $itemsPerPage = 20;
        $chunks = array_chunk($countriesList, $itemsPerPage);
        $currentPage = 0;
        
        $countryListInstance->countries_paginationapple($currentPage, $chunks, $botInstance, $keyboardInstance, $chatId);
        $botInstance->edit_message_text($chatId, $messageId, "به لیست کشور های اپل بازگشتید");
        //$botInstance->delete_message($chatId, $messageId);
    }
    elseif($callbackData && str_contains($callbackData, "igBtn_"))
    {
        $text = "لطفا صبر کنید...";
        $response = $botInstance->sendMessage($chatId, $text);

        $responseDecoded = json_decode($response, true);
        $newMessageId = $responseDecoded['result']['message_id'];
        
        $poolList = $poolListInstance->extract_id_from_pool_list();
        $requestedCountryName = urldecode(str_replace('igBtn_', '', $callbackData));
        $serviceName = "Instagram";
        $priceFromPools = $countryPriceInstance->get_prices($requestedCountryName, $serviceName, $poolList);
        
        $row = 0;
        $keyboardInstance->addInlineButton("📱 نام سرویس: $serviceName", "nonFunctional", null, $row);
        $row++;
        
        if($priceInstance->is_it_time_to_refresh_price(time()))
        {
            $USDT_Price = Util::get_USDT();
            
            if($USDT_Price !== null)
            {
                $priceInstance->refresh_price($USDT_Price);
            }
        }
        $USDT = $priceInstance->get_price();
        $profit = $priceInstance->get_profit();
        
        foreach($priceFromPools as $priceFromPool)
        {
            $tomanPricee = $USDT * $priceFromPool['price'] + $profit;
            $tomanPrice = ceil($tomanPricee / 1000) * 1000;
            $tomanPriceToShow = number_format($tomanPrice, 0);
            
            $keyboardInstance->addInlineButton("💲 قیمت: $tomanPriceToShow", "nonFunctional", null, $row);
            $keyboardInstance->addInlineButton("📡 پنل: {$priceFromPool['pool']}", "igPanel_{$priceFromPool['pool']}_{$priceFromPool['success_rate']}_{$tomanPrice}_$requestedCountryName", null, $row);
            $row++;
        }
        
        $keyboardInstance->addInlineButton("🔙 برگشت به لیست کشور ها", "back_to_ig_countries", null, $row);
        
        $tgNumbersBtn = $keyboardInstance->getInlineKeyboard();
        $botInstance->edit_message_text($chatId, (int)$newMessageId, "لطفا یکی از پنل ها را انتخاب کنید:", $tgNumbersBtn);
    }//444444444444444444444444444444444444444444444444
    elseif($callbackData && str_contains($callbackData, "appleBtn_"))
    {
        $text = "لطفا صبر کنید...";
        $response = $botInstance->sendMessage($chatId, $text);

        $responseDecoded = json_decode($response, true);
        $newMessageId = $responseDecoded['result']['message_id'];
        
        $poolList = $poolListInstance->extract_id_from_pool_list();
        $requestedCountryName = urldecode(str_replace('appleBtn_', '', $callbackData));
        $serviceName = "Apple";
        $priceFromPools = $countryPriceInstance->get_prices($requestedCountryName, $serviceName, $poolList);
        
        $row = 0;
        $keyboardInstance->addInlineButton("📱 نام سرویس: $serviceName", "nonFunctional", null, $row);
        $row++;
        
        if($priceInstance->is_it_time_to_refresh_price(time()))
        {
            $USDT_Price = Util::get_USDT();
            
            if($USDT_Price !== null)
            {
                $priceInstance->refresh_price($USDT_Price);
            }
        }
        $USDT = $priceInstance->get_price();
        $profit = $priceInstance->get_profit();
        
        foreach($priceFromPools as $priceFromPool)
        {
            $tomanPricee = $USDT * $priceFromPool['price'] + $profit;
            $tomanPrice = ceil($tomanPricee / 1000) * 1000;
            $tomanPriceToShow = number_format($tomanPrice, 0);
            
            $keyboardInstance->addInlineButton("💲 قیمت: $tomanPriceToShow", "nonFunctional", null, $row);
            $keyboardInstance->addInlineButton("📡 پنل: {$priceFromPool['pool']}", "applePanel_{$priceFromPool['pool']}_{$priceFromPool['success_rate']}_{$tomanPrice}_$requestedCountryName", null, $row);
            $row++;
        }
        
        $keyboardInstance->addInlineButton("🔙 برگشت به لیست کشور ها", "back_to_apple_countries", null, $row);
        
        $tgNumbersBtn = $keyboardInstance->getInlineKeyboard();
        $botInstance->edit_message_text($chatId, (int)$newMessageId, "لطفا یکی از پنل ها را انتخاب کنید:", $tgNumbersBtn);
    }//PAY111111111111111111111111111111111111111111111111
    elseif($callbackData && str_contains($callbackData, "igPanel_"))
    {
        list($action, $poolId, $success_rate, $tomanPrice, $requestedCountryName) = explode('_', $callbackData);
        $serviceName = "Instagram";
        
        $formatted_message = "📱 <b>سرویس</b> $serviceName\n";
        $formatted_message .= "🌐 <b>کشور: </b> $requestedCountryName\n";
        $formatted_message .= "📡 <b>پنل: </b> $poolId\n";
        $formatted_message .= "💲 <b>قیمت</b> $tomanPrice تومان\n";
        $formatted_message .= "💯 <b>درصد موفقیت:</b>$success_rate\n";

        $keyboardInstance->addInlineButton("💳 پرداخت", "buyIg_{$serviceName}_{$requestedCountryName}_{$poolId}_{$tomanPrice}_{$success_rate}", null);
        $keyboardInstance->addInlineButton("🔙 برگشت به لیست کشور ها", "back_to_ig_countries", null);

        $buyInlineBtn = $keyboardInstance->getInlineKeyboard();

        $botInstance->edit_message_text($chatId, $messageId, $formatted_message, $buyInlineBtn);
        //$botInstance->sendMessage($chatId, $formatted_message, $buyInlineBtn);
    }
    elseif($callbackData && str_contains($callbackData, "buyIg_"))
    {
        list($action, $serviceName, $requestedCountryName, $poolId, $price, $success_rate) = explode('_', $callbackData);
        
        $text = "چند لحظه صبر کنید...";
        $response = $botInstance->sendMessage($chatId, $text);
        
        $responseDecoded = json_decode($response, true);
        $newMessageId = $responseDecoded['result']['message_id'];

        $userBalance = $normalUserInstance->get_user_balance($chatId);
        
        if($userBalance - $price < 0)
        {
            $text = "موجودی کیف پول شما برای خرید این شماره کافی نیست.\n لطفا از طریق منو کیف پول خود را شارژ کنید.";
            $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
            exit();
        }
        
        $buyNumberResult = $buyNumberInstance->buy_number($requestedCountryName, $serviceName, $poolId);
        
        if($buyNumberResult["success"] == 1)
        {
            $paymentInstance->decrease_balance($chatId, $price);
            
            $phone_number = $buyNumberResult['number'];
            $order_id = $buyNumberResult['order_id'];
            $orderid = $buyNumberResult['orderid'];
            $country = $buyNumberResult['country'];
            $service = $buyNumberResult['service'];
            $pool = $buyNumberResult['pool'];
            $expires_in = $buyNumberResult['expires_in'] / 60;
            $cost = $buyNumberResult['cost'];

            $text = "درخواست شما با موفقیت ثبت شد:\n 🔢 شماره: `$phone_number` \n⏰ زمان انقضا: $expires_in دقیقه\n\n❗لطفا شماره خریداری شده را در برنامه موردنظر وارد کنید، سپس به ربات بازگشته و یک مرتبه بر روی دکمه دریافت SMS کلیک کنید. \nمنتظر دریافت کد ورود بمانید.\n به محض ارسال SMS ورود، کد توسط ربات برای شما ارسال خواهد شد.";
            $keyboardInstance->addInlineButton("❌ لغو شماره", "igSMSCancelBtn_{$orderid}_{$price}_{$phone_number}_{$expires_in}", null, 0);
            $keyboardInstance->addInlineButton("📲 دریافت SMS", "igSMSBtn_{$orderid}", null, 0);
            $tgReceiveSms = $keyboardInstance->getInlineKeyboard();
            $botInstance->edit_message_text($chatId, (int)$newMessageId, $text, $tgReceiveSms, "Markdown");
            $userPurchaseInstance->add_user_purchase($chatId, $phone_number, $orderid, $country, $service, $pool, $cost, $price);
        }
        elseif($buyNumberResult["success"] == 0)
        {
            switch($buyNumberResult["type"])
            {
                case "ORDER_FAILED":
                    $text = "مشکلی پیش آمده لطفا با شماره ای دیگر تلاش کنید.";
                    $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
                    break;
                
                case "OUT_OF_STOCK":
                    $text = "متاسفانه شماره‌ای موجود نیست";
                    $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
                    break;
                
                case "PRICE_NOT_FOUND":
                    $text = "ما نتوانستیم پنلی مناسب با قیمت مورد نظر پیدا کنیم. لطفا مجددا تلاش کنید.";
                    $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
                    break;
                
                case "BALANCE_ERROR":
                    for($i = 0; $i < count($admin_chat_ids); $i++)
                    {
                        $botInstance->sendMessage($admin_chat_ids[$i], "موجودی شما کافی نیست. لطفا حساب خود را شارژ کنید.");
                    }
                    $text = "خطا در درخواست.لطفا پس از چند دقیقه مجددا درخواست خود را ارسال کنید.";
                    $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
                    break;
                
                default:
                    $text = "خطای نامشخص";
                    $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
                    break;
            }
        }
        else
        {
            $text = "وضعیت نامشخص. لطفا مجددا تلاش کنید.";
            $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
        }
    }
    elseif($callbackData && str_contains($callbackData, "applePanel_"))
    {
        list($action, $poolId, $success_rate, $tomanPrice, $requestedCountryName) = explode('_', $callbackData);
        $serviceName = "Apple";

        $formatted_message = "📱 <b>سرویس</b> $serviceName\n";
        $formatted_message .= "🌐 <b>کشور: </b> $requestedCountryName\n";
        $formatted_message .= "📡 <b>پنل: </b> $poolId\n";
        $formatted_message .= "💲 <b>قیمت</b> $tomanPrice تومان\n";
        $formatted_message .= "💯 <b>درصد موفقیت:</b>$success_rate\n";

        $keyboardInstance->addInlineButton("💳 پرداخت", "buyApple_{$serviceName}_{$requestedCountryName}_{$poolId}_{$tomanPrice}_{$success_rate}", null);
        $keyboardInstance->addInlineButton("🔙 برگشت به لیست کشور ها", "back_to_apple_countries", null);

        $buyInlineBtn = $keyboardInstance->getInlineKeyboard();

        $botInstance->edit_message_text($chatId, $messageId, $formatted_message, $buyInlineBtn);
        //$botInstance->sendMessage($chatId, $formatted_message, $buyInlineBtn);
    }
    elseif($callbackData && str_contains($callbackData, "buyApple_"))
    {
        list($action, $serviceName, $requestedCountryName, $poolId, $price, $success_rate) = explode('_', $callbackData);
        
        $text = "چند لحظه صبر کنید...";
        $response = $botInstance->sendMessage($chatId, $text);
        
        $responseDecoded = json_decode($response, true);
        $newMessageId = $responseDecoded['result']['message_id'];

        $userBalance = $normalUserInstance->get_user_balance($chatId);
        
        if($userBalance - $price < 0)
        {
            $text = "موجودی کیف پول شما برای خرید این شماره کافی نیست.\n لطفا از طریق منو کیف پول خود را شارژ کنید.";
            $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
            exit();
        }
        
        $buyNumberResult = $buyNumberInstance->buy_number($requestedCountryName, $serviceName, $poolId);
        
        if($buyNumberResult["success"] == 1)
        {
            $paymentInstance->decrease_balance($chatId, $price);
            
            $phone_number = $buyNumberResult['number'];
            $order_id = $buyNumberResult['order_id'];
            $orderid = $buyNumberResult['orderid'];
            $country = $buyNumberResult['country'];
            $service = $buyNumberResult['service'];
            $pool = $buyNumberResult['pool'];
            $expires_in = $buyNumberResult['expires_in'] / 60;
            $cost = $buyNumberResult['cost'];

            $text = "درخواست شما با موفقیت ثبت شد:\n 🔢 شماره: `$phone_number` \n⏰ زمان انقضا: $expires_in دقیقه\n\n❗لطفا شماره خریداری شده را در برنامه موردنظر وارد کنید، سپس به ربات بازگشته و یک مرتبه بر روی دکمه دریافت SMS کلیک کنید. \nمنتظر دریافت کد ورود بمانید.\n به محض ارسال SMS ورود، کد توسط ربات برای شما ارسال خواهد شد.";
            $keyboardInstance->addInlineButton("❌ لغو شماره", "appleSMSCancelBtn_{$orderid}_{$price}_{$phone_number}_{$expires_in}", null, 0);
            $keyboardInstance->addInlineButton("📲 دریافت SMS", "appleSMSBtn_{$orderid}", null, 0);
            $tgReceiveSms = $keyboardInstance->getInlineKeyboard();
            $botInstance->edit_message_text($chatId, (int)$newMessageId, $text, $tgReceiveSms, "Markdown");
            $userPurchaseInstance->add_user_purchase($chatId, $phone_number, $orderid, $country, $service, $pool, $cost, $price);
        }
        elseif($buyNumberResult["success"] == 0)
        {
            switch($buyNumberResult["type"])
            {
                case "ORDER_FAILED":
                    $text = "مشکلی پیش آمده لطفا با شماره ای دیگر تلاش کنید.";
                    $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
                    break;
                
                case "OUT_OF_STOCK":
                    $text = "متاسفانه شماره‌ای موجود نیست";
                    $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
                    break;
                
                case "PRICE_NOT_FOUND":
                    $text = "ما نتوانستیم پنلی مناسب با قیمت مورد نظر پیدا کنیم. لطفا مجددا تلاش کنید.";
                    $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
                    break;
                
                case "BALANCE_ERROR":
                    for($i = 0; $i < count($admin_chat_ids); $i++)
                    {
                        $botInstance->sendMessage($admin_chat_ids[$i], "موجودی شما کافی نیست. لطفا حساب خود را شارژ کنید.");
                    }
                    $text = "خطا در درخواست.لطفا پس از چند دقیقه مجددا درخواست خود را ارسال کنید.";
                    $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
                    break;
                
                default:
                    $text = "خطای نامشخص";
                    $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
                    break;
            }
        }
        else
        {
            $text = "وضعیت نامشخص. لطفا مجددا تلاش کنید.";
            $botInstance->edit_message_text($chatId, (int)$newMessageId, $text);
        }
    }
    //SMS111111111111111111111111111111111111111
    elseif($callbackData && str_contains($callbackData, "tgSMSBtn_"))
    {
        $orderId = str_replace("tgSMSBtn_", "", $callbackData);
        $phone_number = $normalUserInstance->get_user_last_phone_number_by_order_id($orderId);
        $realOrderId = $normalUserInstance->get_user_last_order_id($chatId);
        
        $text = "🔢 شماره: `$phone_number` \n\n";
        $text .= "برای دریافت کد ورود خود بر روی دریافت SMS کلیک کنید، در صورت عدم دریافت کد بعد از چند دقیقه مجددا تلاش کنید.\n بعد از 11 تلاش ناموفق سفارش لغو و مبلغ به کیف پول شما بازمیگردد.";
        $keyboardInstance->addInlineButton("📲 دریافت SMS", "tgSMSBtn_{$orderId}", null, 0);
        $tgReceiveSms = $keyboardInstance->getInlineKeyboard();
        $botInstance->edit_message_text($chatId, $messageId, $text, $tgReceiveSms, "Markdown");

        $last_user_transaction_id = $userPurchaseInstance->get_user_last_transactionId($chatId);
        $last_user_transaction_price = $userPurchaseInstance->get_user_last_transactionPrice($chatId);

        $tries = $normalUserInstance->get_tries($chatId, $realOrderId);

        $checkSmsResults = $checkSmsInstance->receive_sms($realOrderId);

        $found = false;
        foreach ($checkSmsResults as $smsResult)
        {
            if ($smsResult['order_code'] == $realOrderId)
            {
                switch ($smsResult['status'])
                {
                    case "completed":
                        $found = true;
                        $smsCode = $smsResult['code'];
                        $botInstance->sendMessage($chatId, "کد ورود به تلگرام شما: $smsCode");
                        $userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "used");
                        break;

                    case "refunded": 
                        $found = false;
                        $normalUserInstance->add_tries($chatId, $realOrderId);
                        $botInstance->sendMessage($chatId, "خطای کد 6 - لطفا مجددا تلاش کنید.");
                        //$userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "refunded");
                        //$paymentInstance->increase_balance($chatId, $last_user_transaction_price);
                        $cancelSmsInstance->cancel_sms_order($orderId);
                        break;

                    default:  
                        $found = false;
                        $normalUserInstance->add_tries($chatId, $realOrderId);
                        $botInstance->sendMessage($chatId, "خطایی رخ داده است. لطفا بعد از چند دقیقه مجددا تلاش کنید.");
                        //$userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "error");
                        //$paymentInstance->increase_balance($chatId, $last_user_transaction_price);
                        //$cancelSmsInstance->cancel_sms_order($orderId);
                    break;
                }
            }
        }

        if (!$found && $tries == 10)
        {
            $userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "refunded");
            $paymentInstance->increase_balance($chatId, $last_user_transaction_price);
            $cancelSmsInstance->cancel_sms_order($orderId);
            $botInstance->sendMessage($chatId, "مشکلی در سمت منبع پیش آمده.\n سفارش شما برگشت داده شد و مبلغ به کیف پول شما بازگشت.");
        }
    }
//SMS2222222222222222222222222222222222222222
    elseif($callbackData && str_contains($callbackData, "waSMSBtn_"))
    {
        $orderId = str_replace("waSMSBtn_", "", $callbackData);
        $phone_number = $normalUserInstance->get_user_last_phone_number_by_order_id($orderId);
        $realOrderId = $normalUserInstance->get_user_last_order_id($chatId);
        
        $text = "🔢 شماره: `$phone_number` \n\n";
        $text .= "برای دریافت کد ورود خود بر روی دریافت SMS کلیک کنید، در صورت عدم دریافت کد بعد از چند دقیقه مجددا تلاش کنید.\n بعد از 11 تلاش ناموفق سفارش لغو و مبلغ به کیف پول شما بازمیگردد.";
        $keyboardInstance->addInlineButton("📲 دریافت SMS", "tgSMSBtn_{$orderId}", null, 0);
        $tgReceiveSms = $keyboardInstance->getInlineKeyboard();
        $botInstance->edit_message_text($chatId, $messageId, $text, $tgReceiveSms);

        $last_user_transaction_id = $userPurchaseInstance->get_user_last_transactionId($chatId);
        $last_user_transaction_price = $userPurchaseInstance->get_user_last_transactionPrice($chatId);

        $tries = $normalUserInstance->get_tries($chatId, $realOrderId);

        $checkSmsResults = $checkSmsInstance->receive_sms($realOrderId);

        $found = false;
        foreach ($checkSmsResults as $smsResult)
        {
            if ($smsResult['order_code'] == $realOrderId)
            {
                switch ($smsResult['status'])
                {
                    case "completed":
                        $found = true;
                        $smsCode = $smsResult['code'];
                        $botInstance->sendMessage($chatId, "کد ورود به واتس اپ شما: $smsCode");
                        $userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "used");
                        break;

                    case "refunded": 
                        $found = false;
                        $normalUserInstance->add_tries($chatId, $realOrderId);
                        $botInstance->sendMessage($chatId, "خطای کد 6 - لطفا مجددا تلاش کنید.");
                        //$userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "refunded");
                        //$paymentInstance->increase_balance($chatId, $last_user_transaction_price);
                        $cancelSmsInstance->cancel_sms_order($orderId);
                        break;

                    default:  
                        $found = false;
                        $normalUserInstance->add_tries($chatId, $realOrderId);
                        $botInstance->sendMessage($chatId, "خطایی رخ داده است. لطفا بعد از چند دقیقه مجددا تلاش کنید.");
                        //$userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "error");
                        //$paymentInstance->increase_balance($chatId, $last_user_transaction_price);
                        //$cancelSmsInstance->cancel_sms_order($orderId);
                    break;
                }
            }
        }

        if (!$found && $tries == 10)
        {
            $userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "refunded");
            $paymentInstance->increase_balance($chatId, $last_user_transaction_price);
            $cancelSmsInstance->cancel_sms_order($orderId);
            $botInstance->sendMessage($chatId, "مشکلی در سمت منبع پیش آمده.\n سفارش شما برگشت داده شد و مبلغ به کیف پول شما بازگشت.");
        }
    }//SMS3333333333333333333333333333333333333333333
    elseif($callbackData && str_contains($callbackData, "igSMSBtn_"))
    {
        $orderId = str_replace("igSMSBtn_", "", $callbackData);
        $phone_number = $normalUserInstance->get_user_last_phone_number_by_order_id($orderId);
        $realOrderId = $normalUserInstance->get_user_last_order_id($chatId);
        
        $text = "🔢 شماره: `$phone_number` \n\n";
        $text .= "برای دریافت کد ورود خود بر روی دریافت SMS کلیک کنید، در صورت عدم دریافت کد بعد از چند دقیقه مجددا تلاش کنید.\n بعد از 11 تلاش ناموفق سفارش لغو و مبلغ به کیف پول شما بازمیگردد.";
        $keyboardInstance->addInlineButton("📲 دریافت SMS", "tgSMSBtn_{$orderId}", null, 0);
        $tgReceiveSms = $keyboardInstance->getInlineKeyboard();
        $botInstance->edit_message_text($chatId, $messageId, $text, $tgReceiveSms);

        $last_user_transaction_id = $userPurchaseInstance->get_user_last_transactionId($chatId);
        $last_user_transaction_price = $userPurchaseInstance->get_user_last_transactionPrice($chatId);

        $tries = $normalUserInstance->get_tries($chatId, $realOrderId);

        $checkSmsResults = $checkSmsInstance->receive_sms($realOrderId);

        $found = false;
        foreach ($checkSmsResults as $smsResult)
        {
            if ($smsResult['order_code'] == $realOrderId)
            {
                switch ($smsResult['status'])
                {
                    case "completed":
                        $found = true;
                        $smsCode = $smsResult['code'];
                        $botInstance->sendMessage($chatId, "کد ورود به اینستاگرام شما: $smsCode");
                        $userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "used");
                        break;

                    case "refunded": 
                        $found = false;
                        $normalUserInstance->add_tries($chatId, $realOrderId);
                        $botInstance->sendMessage($chatId, "خطای کد 6 - لطفا مجددا تلاش کنید.");
                        //$userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "refunded");
                        //$paymentInstance->increase_balance($chatId, $last_user_transaction_price);
                        $cancelSmsInstance->cancel_sms_order($orderId);
                        break;

                    default:  
                        $found = false;
                        $normalUserInstance->add_tries($chatId, $realOrderId);
                        $botInstance->sendMessage($chatId, "خطایی رخ داده است. لطفا بعد از چند دقیقه مجددا تلاش کنید.");
                        //$userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "error");
                        //$paymentInstance->increase_balance($chatId, $last_user_transaction_price);
                        //$cancelSmsInstance->cancel_sms_order($orderId);
                    break;
                }
            }
        }

        if (!$found && $tries == 10)
        {
            $userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "refunded");
            $paymentInstance->increase_balance($chatId, $last_user_transaction_price);
            $cancelSmsInstance->cancel_sms_order($orderId);
            $botInstance->sendMessage($chatId, "مشکلی در سمت منبع پیش آمده.\n سفارش شما برگشت داده شد و مبلغ به کیف پول شما بازگشت.");
        }
    }//SMS444444444444444444444444444444444444444444
    elseif($callbackData && str_contains($callbackData, "appleSMSBtn_"))
    {
        $orderId = str_replace("appleSMSBtn_", "", $callbackData);
        $phone_number = $normalUserInstance->get_user_last_phone_number_by_order_id($orderId);
        $realOrderId = $normalUserInstance->get_user_last_order_id($chatId);
        
        $text = "🔢 شماره: `$phone_number` \n\n";
        $text .= "برای دریافت کد ورود خود بر روی دریافت SMS کلیک کنید، در صورت عدم دریافت کد بعد از چند دقیقه مجددا تلاش کنید.\n بعد از 11 تلاش ناموفق سفارش لغو و مبلغ به کیف پول شما بازمیگردد.";
        $keyboardInstance->addInlineButton("📲 دریافت SMS", "tgSMSBtn_{$orderId}", null, 0);
        $tgReceiveSms = $keyboardInstance->getInlineKeyboard();
        $botInstance->edit_message_text($chatId, $messageId, $text, $tgReceiveSms);

        $last_user_transaction_id = $userPurchaseInstance->get_user_last_transactionId($chatId);
        $last_user_transaction_price = $userPurchaseInstance->get_user_last_transactionPrice($chatId);

        $tries = $normalUserInstance->get_tries($chatId, $realOrderId);

        $checkSmsResults = $checkSmsInstance->receive_sms($realOrderId);

        $found = false;
        foreach ($checkSmsResults as $smsResult)
        {
            if ($smsResult['order_code'] == $realOrderId)
            {
                switch ($smsResult['status'])
                {
                    case "completed":
                        $found = true;
                        $smsCode = $smsResult['code'];
                        $botInstance->sendMessage($chatId, "کد ورود به اپل شما: $smsCode");
                        $userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "used");
                        break;

                    case "refunded": 
                        $found = false;
                        $normalUserInstance->add_tries($chatId, $realOrderId);
                        $botInstance->sendMessage($chatId, "خطای کد 6 - لطفا مجددا تلاش کنید.");
                        //$userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "refunded");
                        //$paymentInstance->increase_balance($chatId, $last_user_transaction_price);
                        $cancelSmsInstance->cancel_sms_order($orderId);
                        break;

                    default:  
                        $found = false;
                        $normalUserInstance->add_tries($chatId, $realOrderId);
                        $botInstance->sendMessage($chatId, "خطایی رخ داده است. لطفا بعد از چند دقیقه مجددا تلاش کنید.");
                        //$userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "error");
                        //$paymentInstance->increase_balance($chatId, $last_user_transaction_price);
                        //$cancelSmsInstance->cancel_sms_order($orderId);
                    break;
                }
            }
        }

        if (!$found && $tries == 10)
        {
            $userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "refunded");
            $paymentInstance->increase_balance($chatId, $last_user_transaction_price);
            $cancelSmsInstance->cancel_sms_order($orderId);
            $botInstance->sendMessage($chatId, "مشکلی در سمت منبع پیش آمده.\n سفارش شما برگشت داده شد و مبلغ به کیف پول شما بازگشت.");
        }
    }//CANCEL111111111111111111111111111111111111111111111
    elseif($callbackData && str_contains($callbackData, "tgSMSCancelBtn_"))
    {
        list($action, $orderId, $price, $phone_number, $expires_in) = explode('_', $callbackData);

        $text = "🔢 شماره: {$phone_number}\n\n";
        $text .= "⏰ زمان انقضا: {$expires_in} دقیقه\n\n";
        $keyboardInstance->addInlineButton("❌ لغو شماره", "tgSMSCancelBtn_{$orderId}_{$price}_{$phone_number}_{$expires_in}", null, 0);
        $tgCancelSms = $keyboardInstance->getInlineKeyboard();
        $botInstance->edit_message_text($chatId, $messageId, $text, $tgCancelSms);
        
        //$orderId = str_replace("tgSMSCancelBtn_", "", $callbackData);
        $last_user_transaction_id = $userPurchaseInstance->get_user_last_transactionId($chatId);
        //file_put_contents(__DIR__ . "/cancelid.txt",print_r($orderId,true));
        $cancelSmsDetails = $cancelSmsInstance->cancel_sms_order($orderId);
        //file_put_contents(__DIR__ . "/cancelidddddddddd.txt",print_r($cancelSmsDetails,true));
        $cancelResponse = $cancelSmsDetails['response'];
        $cancelHttpCode = $cancelSmsDetails['http_code'];
        
        switch($cancelHttpCode)
        {
            case 404:
                $botInstance->sendMessage($chatId, "شماره سفارش درخواستی پیدا نشد.");
                $userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "error");
            break;
            case 400:
                $botInstance->sendMessage($chatId, "شماره مورد نظر فعلا قابلیت لغو ندارد. چند دقیقه دیگر مجددا تلاش کنید.");
                $userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "error");
            break;
            case 200:
                $userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "canceled");
                $paymentInstance->increase_balance($chatId, $price);
                $botInstance->sendMessage($chatId, "شماره با موفقیت لغو شد و پول به حساب شما بازگشت.");
            break;
            default:
                $botInstance->sendMessage($chatId, "درخواست نامعتبر.");
                $userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "error");
            break;
        }

    }//CANCEL222222222222222222222222222222
    elseif($callbackData && str_contains($callbackData, "waSMSCancelBtn_"))
    {
        list($action, $orderId, $price, $phone_number, $expires_in) = explode('_', $callbackData);

        $text = "🔢 شماره: {$phone_number}\n\n";
        $text .= "⏰ زمان انقضا: {$expires_in} دقیقه\n\n";
        $keyboardInstance->addInlineButton("❌ لغو شماره", "waSMSCancelBtn_{$orderId}_{$price}_{$phone_number}_{$expires_in}", null, 0);
        $tgCancelSms = $keyboardInstance->getInlineKeyboard();
        $botInstance->edit_message_text($chatId, $messageId, $text, $tgCancelSms);
        //$orderId = str_replace("tgSMSCancelBtn_", "", $callbackData);
        $last_user_transaction_id = $userPurchaseInstance->get_user_last_transactionId($chatId);
        //file_put_contents(__DIR__ . "/cancelid.txt",print_r($orderId,true));
        $cancelSmsDetails = $cancelSmsInstance->cancel_sms_order($orderId);
        //file_put_contents(__DIR__ . "/cancelidddddddddd.txt",print_r($cancelSmsDetails,true));
        $cancelResponse = $cancelSmsDetails['response'];
        $cancelHttpCode = $cancelSmsDetails['http_code'];
        
        switch($cancelHttpCode)
        {
            case 404:
                $botInstance->sendMessage($chatId, "شماره سفارش درخواستی پیدا نشد.");
                $userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "error");
            break;
            case 400:
                $botInstance->sendMessage($chatId, "شماره مورد نظر فعلا قابلیت لغو ندارد. چند دقیقه دیگر مجددا تلاش کنید.");
                $userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "error");
            break;
            case 200:
                $userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "canceled");
                $paymentInstance->increase_balance($chatId, $price);
                $botInstance->sendMessage($chatId, "شماره با موفقیت لغو شد و پول به حساب شما بازگشت.");
            break;
            default:
                $botInstance->sendMessage($chatId, "درخواست نامعتبر.");
                $userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "error");
            break;
        }

    }//CANCEL3333333333333333333333
    elseif($callbackData && str_contains($callbackData, "igSMSCancelBtn_"))
    {
        list($action, $orderId, $price, $phone_number, $expires_in) = explode('_', $callbackData);

        $text = "🔢 شماره: {$phone_number}\n\n";
        $text .= "⏰ زمان انقضا: {$expires_in} دقیقه\n\n";
        $keyboardInstance->addInlineButton("❌ لغو شماره", "igSMSCancelBtn_{$orderId}_{$price}_{$phone_number}_{$expires_in}", null, 0);
        $tgCancelSms = $keyboardInstance->getInlineKeyboard();
        $botInstance->edit_message_text($chatId, $messageId, $text, $tgCancelSms);

        //$orderId = str_replace("tgSMSCancelBtn_", "", $callbackData);
        $last_user_transaction_id = $userPurchaseInstance->get_user_last_transactionId($chatId);
        //file_put_contents(__DIR__ . "/cancelid.txt",print_r($orderId,true));
        $cancelSmsDetails = $cancelSmsInstance->cancel_sms_order($orderId);
        //file_put_contents(__DIR__ . "/cancelidddddddddd.txt",print_r($cancelSmsDetails,true));
        $cancelResponse = $cancelSmsDetails['response'];
        $cancelHttpCode = $cancelSmsDetails['http_code'];
        
        switch($cancelHttpCode)
        {
            case 404:
                $botInstance->sendMessage($chatId, "شماره سفارش درخواستی پیدا نشد.");
                $userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "error");
            break;
            case 400:
                $botInstance->sendMessage($chatId, "شماره مورد نظر فعلا قابلیت لغو ندارد. چند دقیقه دیگر مجددا تلاش کنید.");
                $userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "error");
            break;
            case 200:
                $userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "canceled");
                $paymentInstance->increase_balance($chatId, $price);
                $botInstance->sendMessage($chatId, "شماره با موفقیت لغو شد و پول به حساب شما بازگشت.");
            break;
            default:
                $botInstance->sendMessage($chatId, "درخواست نامعتبر.");
                $userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "error");
            break;
        }

    }//CANCEL44444444444444444444444444
    elseif($callbackData && str_contains($callbackData, "appleSMSCancelBtn_"))
    {
        list($action, $orderId, $price, $phone_number, $expires_in) = explode('_', $callbackData);

        $text = "🔢 شماره: {$phone_number}\n\n";
        $text .= "⏰ زمان انقضا: {$expires_in} دقیقه\n\n";
        $keyboardInstance->addInlineButton("❌ لغو شماره", "appleSMSCancelBtn_{$orderId}_{$price}_{$phone_number}_{$expires_in}", null, 0);
        $tgCancelSms = $keyboardInstance->getInlineKeyboard();
        $botInstance->edit_message_text($chatId, $messageId, $text, $tgCancelSms);

        //$orderId = str_replace("tgSMSCancelBtn_", "", $callbackData);
        $last_user_transaction_id = $userPurchaseInstance->get_user_last_transactionId($chatId);
        //file_put_contents(__DIR__ . "/cancelid.txt",print_r($orderId,true));
        $cancelSmsDetails = $cancelSmsInstance->cancel_sms_order($orderId);
        //file_put_contents(__DIR__ . "/cancelidddddddddd.txt",print_r($cancelSmsDetails,true));
        $cancelResponse = $cancelSmsDetails['response'];
        $cancelHttpCode = $cancelSmsDetails['http_code'];
        
        switch($cancelHttpCode)
        {
            case 404:
                $botInstance->sendMessage($chatId, "شماره سفارش درخواستی پیدا نشد.");
                $userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "error");
            break;
            case 400:
                $botInstance->sendMessage($chatId, "شماره مورد نظر فعلا قابلیت لغو ندارد. چند دقیقه دیگر مجددا تلاش کنید.");
                $userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "error");
            break;
            case 200:
                $userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "canceled");
                $paymentInstance->increase_balance($chatId, $price);
                $botInstance->sendMessage($chatId, "شماره با موفقیت لغو شد و پول به حساب شما بازگشت.");
            break;
            default:
                $botInstance->sendMessage($chatId, "درخواست نامعتبر.");
                $userPurchaseInstance->update_user_purchase_status($last_user_transaction_id, "error");
            break;
        }

    }
    elseif($callbackData == "nonFunctional")
    {
        $botInstance->answerCallbackQuery($callbackQuery['id'], "دکمه نمایشی");
    }
    elseif($callbackData == "toServicesBtn")
    {
        $keyboardInstance->addInlineButton("تلگرام", "telegramBtn", null, 0);
        $keyboardInstance->addInlineButton("واتس‌اپ", "whatsappBtn", null, 0);
        $keyboardInstance->addInlineButton("اینستاگرام", "instaBtn", null, 1);
        $keyboardInstance->addInlineButton("اپل", "appleBtn", null, 1);
        $keyboardInstance->addInlineButton("متفرقه", "othersBtn", null, 2);
        $keyboardInstance->addInlineButton("🔙 برگشت", "backToMainMenuBtn", null, 3);
        $serviceKeyboard = $keyboardInstance->getInlineKeyboard();
        $botInstance->edit_message_text($chatId, $messageId, "🔸 لطفا سرویس مورد نظر خود را انتخاب کنید:", $serviceKeyboard);
    }
    elseif($callbackData == "backToTgCountries")
    {
        $countriesList = $countryListInstance->get_countries_by_service("Telegram");
        $itemsPerPage = 20;
        $chunks = array_chunk($countriesList, $itemsPerPage);
        $currentPage = 0;
        
        $countryListInstance->countries_pagination($currentPage, $chunks, $botInstance, $keyboardInstance, $chatId, $messageId);
    }
    elseif($callbackData == "myOrdersBtn")
    {
        $userPurchases = $userPurchaseInstance->get_all_user_purchases($chatId);
        
        if($userPurchases == null)
        {
            $botInstance->sendMessage($chatId, "تا این لحظه شما شماره ای خریداری نکرده اید.");
            return;
        }

        $purchasesChunks = array_chunk($userPurchases, 5);

        foreach($purchasesChunks as $chunk)
        {
            $text = "<b>🛒سفارش‌های شما📡</b>\n\n";

            foreach($chunk as $purchase)
            {
                switch($purchase['status'])
                {
                    case 'used':
                        $purchase['status'] = "استفاده شده";
                        break;
                    case 'canceled':
                        $purchase['status'] = "لغو شده";
                        break;
                      case 'expired':
                        $purchase['status'] = "منقضی شده";
                        break;
                      case 'wating_for_sms':
                        $purchase['status'] = "در انتظار ارسال پیامک";
                        break;
                      case 'refunded':
                        $purchase['status'] = "برگشت داده شده";
                        break;
                      case 'error':
                        $purchase['status'] = "خطا";
                        break;
                }

                $text .= "<b>🔢 شماره: </b>" . $purchase['number'] . "\n";
                $text .= "<b>🌐 کشور: </b>" . $purchase['country'] . "\n";
                $text .= "<b>📱 سرویس: </b>" . $purchase['service'] . "\n";
                $text .= "<b>🔸 وضعیت: </b>" . $purchase['status'] . "\n";
                $text .= "<b>💲 قیمت: </b>" . $purchase['price_in_toman'] . " تومان\n";
                $text .= "<b>📆تاریخ: </b>" . $purchase['created_at'] . "\n";
                $text .= "\n";
                $text .= "💠💠💠💠💠💠💠💠\n";
                $text .= "\n";
            }

            $botInstance->sendMessage($chatId, $text);
        }
    }
    elseif($callbackData == "blockBtn")
    {
        #---------------------------------------------#
        #              Admin Buttons                  # 
        #---------------------------------------------#
        $normalUserInstance->update_user_status($chatId, "blocking_user");

        $keyboardInstance->addInlineButton("انصراف", "adminCancelBtn", null, 0);
        $adminCancelBtn = $keyboardInstance->getInlineKeyboard();

        $text = "لطفا آی دی عددی کاربری که قصد مسدود کردن آن را دارید ارسال کنید.";
        $botInstance->edit_message_text($chatId, $messageId, $text, $adminCancelBtn);
    }
    elseif($callbackData == "adminCancelBtn")
    {
        $normalUserInstance->update_user_status($chatId, "idle");

        $keyboardInstance->addInlineButton("💻 پنل",null,"https://customers.ahpbot.com/virtualNumber/App/Panel/index.php", 0);
        $keyboardInstance->addInlineButton("🚫 مسدود کردن کاربر", "blockBtn", null, 1);
        $keyboardInstance->addInlineButton("🆓 آزاد کردن کاربر", "unblockBtn", null, 1);
        $keyboardInstance->addInlineButton("📧 ارسال پیام خصوصی", "dmBtn", null, 2);
        $keyboardInstance->addInlineButton("👥📧 ارسال پیام گروهی", "groupDmBtn", null, 2);
        $keyboardInstance->addInlineButton("➕ افزایش موجودی", "adminChargingWallet", null, 3);
        $keyboardInstance->addInlineButton("➖ کاهش موجودی", "decreaseChargeWalletBtn", null, 3);
        $keyboardInstance->addInlineButton("ℹ نمایش اطلاعات کاربر", "showUserInfoBtn", null, 4);
        $keyboardInstance->addInlineButton("💳 تنظیم شماره حساب", "bankCardBtn", null, 5);
        $keyboardInstance->addInlineButton("📴 احراز هویت با شماره موبایل", "phoneNumberReuiredBtn", null, 6);
        $keyboardInstance->addInlineButton("👍👎 تایید ادمین برای احراز هویت", "userApprovmentByAdminBtn", null, 7);
        $keyboardInstance->addInlineButton("🤖 حالت به روزرسانی ربات", "botIsUpdatingdBtn", null, 8);
        $mainMenuKeyboard = $keyboardInstance->getInlineKeyboard() ;
        $botInstance->edit_message_text($chatId,$messageId, "به منوی اصلی برگشتید", $mainMenuKeyboard);
    }
    elseif($callbackData == "unblockBtn")
    {
        $normalUserInstance->update_user_status($chatId, "unblocking_user");

        $keyboardInstance->addInlineButton("انصراف", "adminCancelBtn", null, 0);
        $adminCancelBtn = $keyboardInstance->getInlineKeyboard();

        $text = "لطفا آی دی عددی کاربری که قصد آزاد سازی آن را دارید ارسال کنید.";
        $botInstance->edit_message_text($chatId, $messageId, $text, $adminCancelBtn);
    }
    elseif($callbackData == "dmBtn")
    {
        $normalUserInstance->update_user_status($chatId, "direct_message");

        $keyboardInstance->addInlineButton("انصراف", "adminCancelBtn", null, 0);
        $adminCancelBtn = $keyboardInstance->getInlineKeyboard();

        $text = "لطفا آی دی عددی کاربری که قصد پیام دادن به آن را دارید ارسال کنید.";
        $botInstance->edit_message_text($chatId, $messageId, $text, $adminCancelBtn);
    }
    elseif($callbackData == "groupDmBtn")
    {
        $normalUserInstance->update_user_status($chatId, "group_direct_message");

        $keyboardInstance->addInlineButton("انصراف", "adminCancelBtn", null, 0);
        $adminCancelBtn = $keyboardInstance->getInlineKeyboard();

        $text = "لطفا پیام مورد نظر خود را ارسال کنید.";
        $botInstance->edit_message_text($chatId, $messageId, $text, $adminCancelBtn);
    }
    elseif($callbackData == "adminChargingWallet")
    {
        $normalUserInstance->update_user_status($chatId, "adminChargingWallet");

        $keyboardInstance->addInlineButton("انصراف", "adminCancelBtn", null, 0);
        $adminCancelBtn = $keyboardInstance->getInlineKeyboard();

        $text = "لطفا آی دی عددی فردی که قصد افزایش موجودی آن را دارید ارسال کنید.";
        $botInstance->edit_message_text($chatId, $messageId, $text, $adminCancelBtn);
    }
    elseif($callbackData == "decreaseChargeWalletBtn")
    {
        $normalUserInstance->update_user_status($chatId, "adminDecreaseChargeWallet");

        $keyboardInstance->addInlineButton("انصراف", "adminCancelBtn", null, 0);
        $adminCancelBtn = $keyboardInstance->getInlineKeyboard();

        $text = "لطفا آی دی عددی فردی که قصد کاهش موجودی آن را دارید ارسال کنید.";
        $botInstance->edit_message_text($chatId, $messageId, $text, $adminCancelBtn);
    }
    elseif($callbackData == "showUserInfoBtn")
    {
        $normalUserInstance->update_user_status($chatId, "showUserInfo");

        $keyboardInstance->addInlineButton("انصراف", "adminCancelBtn", null, 0);
        $adminCancelBtn = $keyboardInstance->getInlineKeyboard();

        $text = "لطفا آی دی عددی فردی که قصد مشاهده اطلاعات آن را دارید ارسال کنید.";
        $botInstance->edit_message_text($chatId, $messageId, $text, $adminCancelBtn);
    }
    elseif($callbackData && str_contains($callbackData, "approveUser_"))
    {
        $userChatId = str_replace("approveUser_", "", $callbackData);

        $normalUserInstance->update_user_state($userChatId);
        $normalUserInstance->update_user_status($userChatId, "idle");
        $normalUserInstance->update_user_status($chatId, "idle");

        $text = "🔹 درخواست شما توسط ادمین تایید شد.\nلطفا یکی از گزینه های زیر را انتخاب کنید:";
        # Making main menu inline keyboard
        $keyboardInstance->addInlineButton("🔢 خرید سرویس", "buyServiceBtn", null, 0);
        $keyboardInstance->addInlineButton("➕ شارژ کیف پول", "chargeWalletBtn", null, 1);
        $keyboardInstance->addInlineButton("💳 موجودی", "balanceBtn", null, 1);
        $keyboardInstance->addInlineButton("🛒 خرید های من", "myOrdersBtn", null, 2);
        $keyboardInstance->addInlineButton("👨‍💻 ارتباط با پشتیبانی", null, "https://t.me/asus1900", 3);
        $mainMenuKeyboard = $keyboardInstance->getInlineKeyboard();
        $botInstance->sendMessage($userChatId, $text, $mainMenuKeyboard);

        $keyboardInstance->clearInlineButtons();

        $text = "شما کاربر $userChatId را تایید کردید.";
        $botInstance->edit_message_text($chatId, $messageId, $text, $keyboardInstance->admin_main_menu_keyboard());
    }
    elseif($callbackData && str_contains($callbackData, "dontApproveUser_"))
    {
        $userChatId = str_replace("dontApproveUser_", "", $callbackData);

        $normalUserInstance->delete_rejected_user($userChatId);

        $text = "🔹 درخواست شما توسط ادمین رد شد.";
        $botInstance->sendMessage($userChatId, $text);

        $text = "شما کاربر $userChatId را رد کردید.";
        $botInstance->edit_message_text($chatId, $messageId, $text, $keyboardInstance->admin_main_menu_keyboard());
    }
    elseif($callbackData == "bankCardBtn")
    {
        $normalUserInstance->update_user_status($chatId, "settingBankCard");

        $keyboardInstance->addInlineButton("انصراف", "adminCancelBtn", null, 0);
        $adminCancelBtn = $keyboardInstance->getInlineKeyboard();

        $text = "لطفا شماره کارت خود را ارسال کنید.";
        $botInstance->sendMessage($chatId, $text);
    }
    elseif($callbackData == "phoneNumberReuiredBtn")
    {
        $normalUserInstance->must_share_phone_number();
        $result = $normalUserInstance->get_phone_number_config();

        if($result == true)
        {
            $botInstance->answerCallbackQuery($callbackQuery['id'], 'اشتراک گذاری شماره موبایل فعال شد.');
        }
        else
        {
            $botInstance->answerCallbackQuery($callbackQuery['id'], 'اشتراک گذاری شماره موبایل غیر فعال شد.');
        }
    }
    elseif($callbackData == "botIsUpdatingdBtn")
    {
        $normalUserInstance->bot_updating();
        $result = $normalUserInstance->get_bot_update_situation();

        if($result == true)
        {
            $botInstance->answerCallbackQuery($callbackQuery['id'], 'ربات وارد وضعیت به روزرسانی شد.');
        }
        else
        {
            $botInstance->answerCallbackQuery($callbackQuery['id'], 'ربات از وضعیت به روزرسانی خارج شد.');
        }
    }
    elseif($callbackData == "userApprovmentByAdminBtn")
    {
        $normalUserInstance->bot_user_approvment();
        $result = $normalUserInstance->get_bot_user_approvment_situation();

        if($result == true)
        {
            $botInstance->answerCallbackQuery($callbackQuery['id'], 'کاربران جدید برای استفاده از ربات نیاز به تایید شما دارند.');
        }
        else
        {
            $botInstance->answerCallbackQuery($callbackQuery['id'], 'کاربران جدید برای استفاده از ربات نیاز به تایید شما ندارند.');
        }
    }
    
    //$botInstance->answerCallbackQuery($callbackQuery['id'], 'اشتراک مورد نظر انتخاب شد.');
    
    return;
}